function [mapeigs] = eigenmap(xs,period,act_period)
% EIGENMAP2   Find the eigenvalues of the system's Poincare return map
%
% Runs a numerical analysis on the initial conditions for a fixed point.
% The limit cycle code calls step2.m, which calls the function eqns3.dll.
%
% Last modified on 01/23/10 by Robert D. Gregg - rgregg@uiuc.edu
%

global M Mp g L R Kp Kd K p Eref Beta alpha slope modeldir dim wd invalidResults

    if nargin == 1
        period = 1;
        act_period = 1;
    elseif nargin == 2
        act_period = period;
    end

    if act_period > 2
        delta = 1E-4;
        deltadot = 1E-3;
    else
        delta = 1E-4;
        deltadot = 1E-3;
    end

    Omega = zeros(dim,dim);
    Y = zeros(dim,dim);

    if nargin < 2
        period = 1;
    end

    if nargin == 0
        fprintf('Error: must input initial state!\n')
    end

    for i=1:dim
        if(i<=dim/2)
            x = xs; x(i) = x(i) - delta;
            Y(i,i) = delta;
        else
            x = xs; x(i) = x(i) - deltadot;
            Y(i,i) = deltadot;
        end
        v = walk(x,period);
        Omega(:,i) = v'-xs';
    end
    A = Omega/Y;
    mapeigs = eig(A);
    fprintf('max(abs(eigenvalues))=%f\n',max(abs(mapeigs)));
end