function [gaitnorm,A,B,C,D] = gait_sensitivity_norm(x0,g0,period)
%
% Runs a numerical analysis on the initial conditions for a fixed point.
% See: A Disturbance Rejection Measure for Limit Cycle Walkers: The Gait Sensitivity Norm, Daan G. E. Hobbelen and Martijn Wisse
%   for detailed explanation of algorithm
% Last modified on 07/03/2018 by Mark Yeatman

% Note: There's some hardcoded values in here specific to the flat foot
% walker problem. Hopefully I'll come back and generalize this. 

% According to the paper, the way to use this value is to compare
% 1/gaitnorm. A high value indicates more robust. 
global slope silent
    
    %Run (5) steps to find "the real" fixed point. If you're varying parameters and using
    %the same x0 all the time, this is probably necessary. 
    [x0,~,~,out_extra] = walk(x0,5); 
    g0 = [out_extra.step_lengths(end);out_extra.step_time(end);out_extra.clearance_heel(end)]';
    
    if nargin < 3
        period = 1;
    end

    if nargin == 0
        fprintf('Error: must input initial state!\n')
    end
    
    perturb_v = 1E-4;
    perturb_v_dot = 1E-3;

    %dv = zeros(length(x0),1);
    %delta_x = zeros(length(x0),length(x0));
    elen = 3;
    A = zeros(length(x0),length(x0)); %length(x0) x length(x0)
    B = zeros(length(x0),elen); %length(x0) x size(e);
    C = zeros(length(g0),length(x0)); % size(g) x length(x0);
    D = zeros(length(g0),elen);  % size(g) x size(e);
    gnorm = [0.1,0.1,0.1];
    
    %state space perturbation
    for i=1:length(x0)
        x = x0; 
        if(i<=length(x0)/2)
            x(i) = x(i) - perturb_v;
            delta_x = perturb_v;
        else 
            x(i) = x(i) - perturb_v_dot;
            delta_x = perturb_v_dot;
        end
        [x_p,~,~,out_extra] = walk(x,period); %simulation function call!
        g_p = [out_extra.step_lengths(end);out_extra.step_time(end);out_extra.clearance_heel(end)]';%step length, step time, minimum ground clearance heel over the stride

        dv = x_p'-x0';
        dg = (g_p'-g0')./gnorm';
        A(:,i) = dv/delta_x;
        C(:,i) = dg/delta_x;
    end

    
    %disturbance e 
    e = 0;
    slopedelta = 1;
    perturb = zeros(1,16);
    for i = 1:elen
        x = x0; 
        if i == 1 %slope variation +1 rad
            slope = slope+deg2rad(slopedelta);
            e = slopedelta;           
            if ~silent;disp(slope);end
        elseif i == 2 %slope variation -1 rad
            slope = slope-deg2rad(2*slopedelta);
            e = -slopedelta;
            if ~silent;disp(slope);end
        elseif i == 3 %kinetic energy increase 
            slope = slope+deg2rad(slopedelta); %fix the slope
            perturb(11:end) = 0.4*x(11:end);    
            if ~silent;disp(0.4);end
        end
        [x_p,~,~,out_extra] = walk(x+perturb,period); %simulation function call!
        g_p = [out_extra.step_lengths(end);out_extra.step_time(end);out_extra.clearance_heel(end)]'; %step length, step time, ground clearance heel at x(6) = -0.1
        dv = x_p'-x0';
        dg = (g_p'-g0')./gnorm';
        B(:,i) = dv/e;
        D(:,i) = dg/e;
    end

    %25 iterations is somewhat arbitrary, the formula calls for the sum
    %from i=1 : inf, but you're got to stop somewhere. Ideally termination criteria should be
    %based on the eigenvalues of A. But I'm lazy.
    part = 0;
    for i=1:25
        part = part + trace( B' * A'^i * (C' * C) * A^i * B);
    end
    gaitnorm = trace(D'*D) + part;

end