function [out] = dynamics(~, x, flag)
% Input: x = [q, qdot]
%        q = [x, y, global angle, stance ankle, stance knee, hip, swing knee, swing ankle]
global dim contact step
global M1 M2 Mp Mf la l1 l2 lf I1x I2x Ipx  %mass/geometry parameters for EOM
global slope
global Kd1 Kd2 Kp1 Kp2 temp_Kp %PD control parameters
global g
if nargin < 3, flag = 's'; end
if x(3) > pi/2 || x(3) < - pi/2 
   %checks heel angle to see if out of bounds
   error('biped has fallen through the floor');
end

switch flag
    case{'s','u','b'}
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Calculate the dynamics 's'
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %PD control 
        q = x(1:dim/2);
        qdot = x(dim/2+1:dim);
        Kd = diag([0, 0, 0, Kd1, Kd2, 2*sqrt(temp_Kp)*1.3, 2*sqrt(temp_Kp)*.7, 2*sqrt(temp_Kp)*.03]);
        Kp = diag([0, 0, 0, Kp1, Kp2, temp_Kp, temp_Kp, temp_Kp]);
        setpos = [0, 0, 0, 0.01, -0.05, -0.5, 0.2, -0.25]';      
        u_pd = -Kp*(q-setpos) - Kd*qdot;  
                        
        %Dynamics matrices
        Mmtx = Mfunc(x);
        Cmtx = Cfunc(x);
        Nvect = Gfunc(x);
                
        %Define contact constraints and energies for 3 different configurations  
        if strcmp(contact,'heel')
            Avect=zeros(2,8);
            Avect(1,1)=1;Avect(2,2)=1;
            Adot=zeros(2,dim/2);

        elseif strcmp(contact,'flat')
            Avect=[eye(3),zeros(3,5)];
            Adot=zeros(3,dim/2);

        elseif strcmp(contact,'toe')
            Avect=zeros(2,8); Adot=zeros(2,8);
            Avect(1,1)=1;Avect(1,3)=lf*sin(x(3));Avect(2,2)=1;Avect(2,3)=-lf*cos(x(3));
            Adot(1,3)=lf*cos(x(3))*x(11);Adot(2,3)=lf*sin(x(3))*x(11);      
        end
         
        u = u_pd;
        
        %Joint accelerations
        Lambda = ((Avect/Mmtx)*Avect')\((Avect/Mmtx)*(u - Cmtx*qdot - Nvect) + Adot*qdot);
        accel = Mmtx\(-Cmtx*qdot-Nvect-Avect'*Lambda + u);
        
        accel(1:2) = 0;
        qdot(1:2)=0;
        if strcmp(contact,'flat')
            accel(3) = 0;
            qdot(3)=0;
        end
        
        %set output
        out(1:dim/2) = qdot;
        out(dim/2+1:dim) = accel;        
        out = out';
        
        %Output torques
        if flag == 'u'
            out = u_pd;
        end
        
        %Output center of pressure
        if flag =='b'
            Lambdax=Lambda(1,:);Lambday=Lambda(2,:);LambdaM=Lambda(3,:);
            COPx=LambdaM/(sin(slope)*Lambdax-cos(slope)*Lambday);
            out=COPx; 
        end  
    case 'f'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculate the foot-slap impact map 'f'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        Avect=[eye(3),zeros(3,5)];
        Mmtx = Mfunc(x);

        q = x(1:dim/2);
        qdot = x(dim/2+1:dim);

        ref = Mmtx\Avect';
        Li = (Avect*ref)\(Avect*qdot);

        out = [q; qdot - ref*Li];
    case 'h'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculate the toe-off impact map 'h'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % the q and qdot here should be pre-impact state vector, therefore
        q=x(1:dim/2); qdot=x(dim/2+1:end);
        q(1:2)=[cos(slope), -sin(slope); sin(slope), cos(slope)]*[lf;0];
        out=[q;qdot];
    case 'p'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculate the equivalent COP right after the impact 'p'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % Use the constraint matrix after impact (A2), but the 'qdot' before impact

        Avect=[eye(3),zeros(3,5)];   % Avect=A2
        Mmtx = Mfunc(x);        

        qdot=x(dim/2+1:end);
        ref = Mmtx\Avect';
        Lamdaforce= (Avect*ref)\(Avect*qdot);

        Lamdax=Lamdaforce(1,:);Lamday=Lamdaforce(2,:);LamdaM=Lamdaforce(3,:);
        Cop_original=LamdaM/(sin(slope)*Lamdax-cos(slope)*Lamday);

        out(1)=Cop_original;
        out(2)=Lamdax;
        out(3)=Lamday;
        out(4)=LamdaM;
    case 'i'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculate the ground impact map 'i' (Heel-contact map)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %     New transition map
        FullMatrix=zeros(10,10);
        FullMatrix(1,:) =[2.*M1+2.*M2+2.*Mf+Mp,...
        0,...
        (1/2).*((-1).*la.*(4.*M1+4.*M2+3.*Mf+2.*Mp).*cos(x(3))+(-1).*l1.*(3.*M1+2.*(2.*M2+Mf+Mp)).*cos(x(3)+x(4))+(-2).*l2.*M1.*cos(x(3)+x(4)+x(5))+(-3).*l2.*M2.*cos(x(3)+x(4)+x(5))+(-2).*l2.*Mf.*cos(x(3)+x(4)+x(5))+(-2).*l2.*Mp.*cos(x(3)+x(4)+x(5))+2.*l2.*M1.*cos(x(3)+x(4)+x(5)+x(6))+l2.*M2.*cos(x(3)+x(4)+x(5)+x(6))+2.*l2.*Mf.*cos(x(3)+x(4)+x(5)+x(6))+l1.*M1.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+2.*l1.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))),...
        (1/2).*((-1).*l1.*(3.*M1+2.*(2.*M2+Mf+Mp)).*cos(x(3)+x(4))+(-1).*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(3)+x(4)+x(5))+2.*l2.*M1.*cos(x(3)+x(4)+x(5)+x(6))+l2.*M2.*cos(x(3)+x(4)+x(5)+x(6))+2.*l2.*Mf.*cos(x(3)+x(4)+x(5)+x(6))+l1.*M1.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+2.*l1.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))),...
        (1/2).*((-1).*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(3)+x(4)+x(5))+l2.*(2.*M1+M2+2.*Mf).*cos(x(3)+x(4)+x(5)+x(6))+l1.*M1.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+2.*l1.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))),...
        (1/2).*(l2.*(2.*M1+M2+2.*Mf).*cos(x(3)+x(4)+x(5)+x(6))+l1.*(M1+2.*Mf).*cos(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))),...
        (1/2).*(l1.*(M1+2.*Mf).*cos(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))),...
        (1/2).*la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),...
        (-1),...
        0];

        FullMatrix(2,:) =[0,2.*M1+2.*M2+2.*Mf+Mp,(1/2).*((-1).*la.*(4.*M1+4.*M2+3.* ...
        Mf+2.*Mp).*sin(x(3))+(-1).*l1.*(3.*M1+2.*(2.*M2+Mf+Mp)).* ...
        sin(x(3)+x(4))+(-2).*l2.*M1.*sin(x(3)+x(4)+x(5))+(-3).*l2.* ...0
        M2.*sin(x(3)+x(4)+x(5))+(-2).*l2.*Mf.*sin(x(3)+x(4)+x(5))+( ...
        -2).*l2.*Mp.*sin(x(3)+x(4)+x(5))+2.*l2.*M1.*sin(x(3)+x(4)+x( ...
        5)+x(6))+l2.*M2.*sin(x(3)+x(4)+x(5)+x(6))+2.*l2.*Mf.*sin(x( ...
        3)+x(4)+x(5)+x(6))+l1.*M1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+2.* ...
        l1.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*sin(x(3)+x(4)+ ...
        x(5)+x(6)+x(7)+x(8))),(1/2).*((-1).*l1.*(3.*M1+2.*(2.*M2+Mf+ ...
        Mp)).*sin(x(3)+x(4))+(-1).*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).* ...
        sin(x(3)+x(4)+x(5))+2.*l2.*M1.*sin(x(3)+x(4)+x(5)+x(6))+l2.* ...
        M2.*sin(x(3)+x(4)+x(5)+x(6))+2.*l2.*Mf.*sin(x(3)+x(4)+x(5)+ ...
        x(6))+l1.*M1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+2.*l1.*Mf.*sin( ...
        x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x( ...
        7)+x(8))),(1/2).*((-1).*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).*sin(x( ...
        3)+x(4)+x(5))+l2.*(2.*M1+M2+2.*Mf).*sin(x(3)+x(4)+x(5)+x(6)) ...
        +l1.*M1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+2.*l1.*Mf.*sin(x(3)+ ...
        x(4)+x(5)+x(6)+x(7))+la.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x( ...
        8))),(1/2).*(l2.*(2.*M1+M2+2.*Mf).*sin(x(3)+x(4)+x(5)+x(6))+ ...
        l1.*(M1+2.*Mf).*sin(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*sin(x( ...
        3)+x(4)+x(5)+x(6)+x(7)+x(8))),(1/2).*(l1.*(M1+2.*Mf).*sin(x( ...
        3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7) ...
        +x(8))),(1/2).*la.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),0, ...
        (-1)];

        FullMatrix(3,:) = [(1/2).*((-1).*la.*(4.*M1+4.*M2+3.*Mf+2.*Mp).*cos(x(3))+(-1).*l1.*(3.*M1+2.*(2.*M2+Mf+Mp)).*cos(x(3)+x(4))+(-2).*l2.* ...
        M1.*cos(x(3)+x(4)+x(5))+(-3).*l2.*M2.*cos(x(3)+x(4)+x(5))+(-2).*l2.*Mf.*cos(x(3)+x(4)+x(5))+(-2).*l2.*Mp.*cos(x(3)+x(4)+ ...
        x(5))+2.*l2.*M1.*cos(x(3)+x(4)+x(5)+x(6))+l2.*M2.*cos(x(3)+ ...
        x(4)+x(5)+x(6))+2.*l2.*Mf.*cos(x(3)+x(4)+x(5)+x(6))+l1.*M1.* ...
        cos(x(3)+x(4)+x(5)+x(6)+x(7))+2.*l1.*Mf.*cos(x(3)+x(4)+x(5)+ ...
        x(6)+x(7))+la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))),...
        (1/2).*((-1).*la.*(4.*M1+4.*M2+3.*Mf+2.*Mp).*sin(x(3))+(-1).*l1.* ...
        (3.*M1+2.*(2.*M2+Mf+Mp)).*sin(x(3)+x(4))+(-2).*l2.*M1.*sin( ...
        x(3)+x(4)+x(5))+(-3).*l2.*M2.*sin(x(3)+x(4)+x(5))+(-2).*l2.* ...
        Mf.*sin(x(3)+x(4)+x(5))+(-2).*l2.*Mp.*sin(x(3)+x(4)+x(5))+ ...
        2.*l2.*M1.*sin(x(3)+x(4)+x(5)+x(6))+l2.*M2.*sin(x(3)+x(4)+x(5)+x(6))+...
        2.*l2.*Mf.*sin(x(3)+x(4)+x(5)+x(6))+l1.*M1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+2.*l1.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+ ...
        x(7))+la.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))),...
        2.*I1x+2.*I2x+Ipx+(1/4).*la.^2.*Mf+(1/4).*M1.*(l1+2.*la.*cos(x(4))).^2+Mp.*(l2+l1.*cos(x(5))+la.*cos(x(4)+x(5))).^2+(1/4).*M2.* ...
        (l2+2.*l1.*cos(x(5))+2.*la.*cos(x(4)+x(5))).^2+(1/4).*M2.*( ...
        l2+(-2).*l2.*cos(x(6))+(-2).*l1.*cos(x(5)+x(6))+(-2).*la.* ...
        cos(x(4)+x(5)+x(6))).^2+M1.*((-1/2).*l1+(-1).*l2.*cos(x(7))+ ...
        l2.*cos(x(6)+x(7))+l1.*cos(x(5)+x(6)+x(7))+la.*cos(x(4)+x(5)+x(6)+x(7))).^2+Mf.*((-1/2).*la+(-1).*l1.*cos(x(8))+(-1).* ...
        l2.*cos(x(7)+x(8))+l2.*cos(x(6)+x(7)+x(8))+l1.*cos(x(5)+x(6)+x(7)+x(8))+la.*cos(x(4)+x(5)+x(6)+x(7)+x(8))).^2+la.^2.* ...
        M1.*sin(x(4)).^2+M2.*(l1.*sin(x(5))+la.*sin(x(4)+x(5))).^2+ ...
        Mp.*(l1.*sin(x(5))+la.*sin(x(4)+x(5))).^2+M2.*(l2.*sin(x(6))+l1.*sin(x(5)+x(6))+la.*sin(x(4)+x(5)+x(6))).^2+M1.*((-1).* ...
        l2.*sin(x(7))+l2.*sin(x(6)+x(7))+l1.*sin(x(5)+x(6)+x(7))+ ...
        la.*sin(x(4)+x(5)+x(6)+x(7))).^2+Mf.*((-1).*l1.*sin(x(8))+( ...
        -1).*l2.*sin(x(7)+x(8))+l2.*sin(x(6)+x(7)+x(8))+l1.*sin(x(5)+x(6)+x(7)+x(8))+la.*sin(x(4)+x(5)+x(6)+x(7)+x(8))).^2,...
        (1/4).*(8.*I1x+8.*I2x+4.*Ipx+6.*l1.^2.*M1+8.*l2.^2.*M1+8.*l1.^2.* ...
        M2+6.*l2.^2.*M2+8.*l1.^2.*Mf+8.*l2.^2.*Mf+la.^2.*Mf+4.* ...
        l1.^2.*Mp+4.*l2.^2.*Mp+2.*l1.*la.*(3.*M1+2.*(2.*M2+Mf+Mp)).* ...
        cos(x(4))+4.*l1.*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(5))+4.* ...
        l2.*la.*M1.*cos(x(4)+x(5))+6.*l2.*la.*M2.*cos(x(4)+x(5))+4.* ...
        l2.*la.*Mf.*cos(x(4)+x(5))+4.*l2.*la.*Mp.*cos(x(4)+x(5))+(-8).*l2.^2.*M1.*cos(x(6))+(-4).*l2.^2.*M2.*cos(x(6))+(-8).* ...
        l2.^2.*Mf.*cos(x(6))+(-8).*l1.*l2.*M1.*cos(x(5)+x(6))+(-4).* ...
        l1.*l2.*M2.*cos(x(5)+x(6))+(-8).*l1.*l2.*Mf.*cos(x(5)+x(6))+ ...
        (-4).*l2.*la.*M1.*cos(x(4)+x(5)+x(6))+(-2).*l2.*la.*M2.*cos(x(4)+x(5)+x(6))+(-4).*l2.*la.*Mf.*cos(x(4)+x(5)+x(6))+4.* ...
        l1.*l2.*M1.*cos(x(7))+8.*l1.*l2.*Mf.*cos(x(7))+(-4).*l1.* ...
        l2.*M1.*cos(x(6)+x(7))+(-8).*l1.*l2.*Mf.*cos(x(6)+x(7))+(-4).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+(-8).*l1.^2.*Mf.*cos(x(5)+ ...
        x(6)+x(7))+(-2).*l1.*la.*M1.*cos(x(4)+x(5)+x(6)+x(7))+(-4).* ...
        l1.*la.*Mf.*cos(x(4)+x(5)+x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos(x(7)+x(8))+(-4).*l2.*la.*Mf.*cos(x(6)+ ...
        x(7)+x(8))+(-4).*l1.*la.*Mf.*cos(x(5)+x(6)+x(7)+x(8))+(-2).* ...
        la.^2.*Mf.*cos(x(4)+x(5)+x(6)+x(7)+x(8))),...
        (1/4).*(4.*I1x+8.*I2x+4.*Ipx+l1.^2.*M1+8.*l2.^2.*M1+6.*l2.^2.*M2+4.*l1.^2.*Mf+ ...
        8.*l2.^2.*Mf+la.^2.*Mf+4.*l2.^2.*Mp+2.*l1.*l2.*(2.*M1+3.*M2+ ...
        2.*(Mf+Mp)).*cos(x(5))+2.*l2.*la.*(2.*M1+3.*M2+2.*(Mf+Mp)).* ...
        cos(x(4)+x(5))+(-8).*l2.^2.*M1.*cos(x(6))+(-4).*l2.^2.*M2.* ...
        cos(x(6))+(-8).*l2.^2.*Mf.*cos(x(6))+(-4).*l1.*l2.*M1.*cos(x(5)+x(6))+(-2).*l1.*l2.*M2.*cos(x(5)+x(6))+(-4).*l1.*l2.* ...
        Mf.*cos(x(5)+x(6))+(-4).*l2.*la.*M1.*cos(x(4)+x(5)+x(6))+(-2).*l2.*la.*M2.*cos(x(4)+x(5)+x(6))+(-4).*l2.*la.*Mf.*cos( ...
        x(4)+x(5)+x(6))+4.*l1.*l2.*M1.*cos(x(7))+8.*l1.*l2.*Mf.*cos(x(7))+(-4).*l1.*l2.*M1.*cos(x(6)+x(7))+(-8).*l1.*l2.*Mf.* ...
        cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+(-4).* ...
        l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+(-2).*l1.*la.*M1.*cos(x(4)+...
        x(5)+x(6)+x(7))+(-4).*l1.*la.*Mf.*cos(x(4)+x(5)+x(6)+x(7))+4.* ...
        l1.*la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos(x(7)+x(8))+(-4).* ...
        l2.*la.*Mf.*cos(x(6)+x(7)+x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+ ...
        x(6)+x(7)+x(8))+(-2).*la.^2.*Mf.*cos(x(4)+x(5)+x(6)+x(7)+x(8))),...
        I1x+I2x+(1/4).*l2.*M2.*(l2+(-2).*l2.*cos(x(6))+(-2).* ...
        l1.*cos(x(5)+x(6))+(-2).*la.*cos(x(4)+x(5)+x(6)))+(-1/4).* ...
        M1.*(l1+2.*l2.*cos(x(7))).*((-1).*l1+(-2).*l2.*cos(x(7))+2.* ...
        l2.*cos(x(6)+x(7))+2.*l1.*cos(x(5)+x(6)+x(7))+2.*la.*cos(x(4)+x(5)+x(6)+x(7)))+...
        Mf.*((1/2).*la+l1.*cos(x(8))+l2.*cos(x(7)+x(8))).*((1/2).*la+l1.*cos(x(8))+l2.*cos(x(7)+x(8))+(-1).*l2.*cos(x(6)+x(7)+x(8))+(-1).*l1.*cos(x(5)+x(6)+x(7)+x(8))+ ...
        (-1).*la.*cos(x(4)+x(5)+x(6)+x(7)+x(8)))+(-1).*l2.*M1.*sin(x(7)).*((-1).*l2.*sin(x(7))+l2.*sin(x(6)+x(7))+l1.*sin(x(5)+ ...
        x(6)+x(7))+la.*sin(x(4)+x(5)+x(6)+x(7)))+(-1).*Mf.*(l1.*sin(x(8))+l2.*sin(x(7)+x(8))).*((-1).*l1.*sin(x(8))+(-1).*l2.* ...
        sin(x(7)+x(8))+l2.*sin(x(6)+x(7)+x(8))+l1.*sin(x(5)+x(6)+x(7)+x(8))+...
        la.*sin(x(4)+x(5)+x(6)+x(7)+x(8))),...
        I1x+(-1/4).*l1.*M1.*((-1).*l1+(-2).*l2.*cos(x(7))+2.*l2.*cos(x(6)+x(7))+2.* ...
        l1.*cos(x(5)+x(6)+x(7))+2.*la.*cos(x(4)+x(5)+x(6)+x(7)))+ ...
        Mf.*((1/2).*la+l1.*cos(x(8))).*((1/2).*la+l1.*cos(x(8))+l2.* ...
        cos(x(7)+x(8))+(-1).*l2.*cos(x(6)+x(7)+x(8))+(-1).*l1.*cos(x(5)+x(6)+x(7)+x(8))+(-1).*la.*cos(x(4)+x(5)+x(6)+x(7)+x(8)))+(-1).*l1.*Mf.*sin(x(8)).*((-1).*l1.*sin(x(8))+(-1).*l2.* ...
        sin(x(7)+x(8))+l2.*sin(x(6)+x(7)+x(8))+l1.*sin(x(5)+x(6)+x(7)+x(8))+la.*sin(x(4)+x(5)+x(6)+x(7)+x(8))),...
        (1/2).*la.*Mf.*((1/2).*la+l1.*cos(x(8))+l2.*cos(x(7)+x(8))+(-1).*l2.*cos(x(6)+x(7)+x(8))+(-1).*l1.*cos(x(5)+x(6)+x(7)+x(8))+(-1).*la.* ...
        cos(x(4)+x(5)+x(6)+x(7)+x(8))),...
        la.*cos(x(3))+l1.*cos(x(3)+x(4))+l2.*cos(x(3)+x(4)+x(5))+(-1).*l2.*cos(x(3)+x(4)+x(5)+x(6))+(-1).*l1.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+(-1).*la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),...
        la.*sin(x(3))+l1.*sin(x(3)+x(4))+l2.*sin(x(3)+x(4)+x(5))+(-1).*l2.*sin(x(3)+x(4)+x(5)+x(6))+ ...
        (-1).*l1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+(-1).*la.*sin(x(3)+ ...
        x(4)+x(5)+x(6)+x(7)+x(8))];

        FullMatrix(4,:) =[(1/2).*((-1).*l1.*(3.*M1+2.*(2.*M2+Mf+Mp)).*cos(x(3)+x(4))+ ...
        (-1).*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(3)+x(4)+x(5))+2.* ...
        l2.*M1.*cos(x(3)+x(4)+x(5)+x(6))+l2.*M2.*cos(x(3)+x(4)+x(5)+ ...
        x(6))+2.*l2.*Mf.*cos(x(3)+x(4)+x(5)+x(6))+l1.*M1.*cos(x(3)+ ...
        x(4)+x(5)+x(6)+x(7))+2.*l1.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7) ...
        )+la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))),(1/2).*((-1).* ...
        l1.*(3.*M1+2.*(2.*M2+Mf+Mp)).*sin(x(3)+x(4))+(-1).*l2.*(2.* ...
        M1+3.*M2+2.*(Mf+Mp)).*sin(x(3)+x(4)+x(5))+2.*l2.*M1.*sin(x( ...
        3)+x(4)+x(5)+x(6))+l2.*M2.*sin(x(3)+x(4)+x(5)+x(6))+2.*l2.* ...
        Mf.*sin(x(3)+x(4)+x(5)+x(6))+l1.*M1.*sin(x(3)+x(4)+x(5)+x(6) ...
        +x(7))+2.*l1.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*sin( ...
        x(3)+x(4)+x(5)+x(6)+x(7)+x(8))),(1/4).*(8.*I1x+8.*I2x+4.* ...
        Ipx+6.*l1.^2.*M1+8.*l2.^2.*M1+8.*l1.^2.*M2+6.*l2.^2.*M2+8.* ...
        l1.^2.*Mf+8.*l2.^2.*Mf+la.^2.*Mf+4.*l1.^2.*Mp+4.*l2.^2.*Mp+ ...
        2.*l1.*la.*(3.*M1+2.*(2.*M2+Mf+Mp)).*cos(x(4))+4.*l1.*l2.*( ...
        2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(5))+4.*l2.*la.*M1.*cos(x(4)+ ...
        x(5))+6.*l2.*la.*M2.*cos(x(4)+x(5))+4.*l2.*la.*Mf.*cos(x(4)+ ...
        x(5))+4.*l2.*la.*Mp.*cos(x(4)+x(5))+(-8).*l2.^2.*M1.*cos(x( ...
        6))+(-4).*l2.^2.*M2.*cos(x(6))+(-8).*l2.^2.*Mf.*cos(x(6))+( ...
        -8).*l1.*l2.*M1.*cos(x(5)+x(6))+(-4).*l1.*l2.*M2.*cos(x(5)+ ...
        x(6))+(-8).*l1.*l2.*Mf.*cos(x(5)+x(6))+(-4).*l2.*la.*M1.* ...
        cos(x(4)+x(5)+x(6))+(-2).*l2.*la.*M2.*cos(x(4)+x(5)+x(6))+( ...
        -4).*l2.*la.*Mf.*cos(x(4)+x(5)+x(6))+4.*l1.*l2.*M1.*cos(x(7) ...
        )+8.*l1.*l2.*Mf.*cos(x(7))+(-4).*l1.*l2.*M1.*cos(x(6)+x(7))+ ...
        (-8).*l1.*l2.*Mf.*cos(x(6)+x(7))+(-4).*l1.^2.*M1.*cos(x(5)+ ...
        x(6)+x(7))+(-8).*l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+(-2).*l1.* ...
        la.*M1.*cos(x(4)+x(5)+x(6)+x(7))+(-4).*l1.*la.*Mf.*cos(x(4)+ ...
        x(5)+x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos( ...
        x(7)+x(8))+(-4).*l2.*la.*Mf.*cos(x(6)+x(7)+x(8))+(-4).*l1.* ...
        la.*Mf.*cos(x(5)+x(6)+x(7)+x(8))+(-2).*la.^2.*Mf.*cos(x(4)+ ...
        x(5)+x(6)+x(7)+x(8))),2.*I1x+2.*I2x+Ipx+(1/4).*l1.^2.*M1+ ...
        Mp.*(l2+l1.*cos(x(5))).^2+(1/4).*M2.*(l2+2.*l1.*cos(x(5))) ...
        .^2+(1/4).*M2.*(l2+(-2).*l2.*cos(x(6))+(-2).*l1.*cos(x(5)+x( ...
        6))).^2+M1.*((-1/2).*l1+(-1).*l2.*cos(x(7))+l2.*cos(x(6)+x( ...
        7))+l1.*cos(x(5)+x(6)+x(7))).^2+Mf.*((1/2).*la+l1.*cos(x(8)) ...
        +l2.*cos(x(7)+x(8))+(-1).*l2.*cos(x(6)+x(7)+x(8))+(-1).*l1.* ...
        cos(x(5)+x(6)+x(7)+x(8))).^2+l1.^2.*M2.*sin(x(5)).^2+l1.^2.* ...
        Mp.*sin(x(5)).^2+M2.*(l2.*sin(x(6))+l1.*sin(x(5)+x(6))).^2+ ...
        M1.*((-1).*l2.*sin(x(7))+l2.*sin(x(6)+x(7))+l1.*sin(x(5)+x( ...
        6)+x(7))).^2+Mf.*(l1.*sin(x(8))+l2.*sin(x(7)+x(8))+(-1).* ...
        l2.*sin(x(6)+x(7)+x(8))+(-1).*l1.*sin(x(5)+x(6)+x(7)+x(8))) ...
        .^2,(1/4).*(4.*I1x+8.*I2x+4.*Ipx+l1.^2.*M1+8.*l2.^2.*M1+6.* ...
        l2.^2.*M2+4.*l1.^2.*Mf+8.*l2.^2.*Mf+la.^2.*Mf+4.*l2.^2.*Mp+ ...
        2.*l1.*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(5))+(-4).*l2.^2.* ...
        (2.*M1+M2+2.*Mf).*cos(x(6))+(-4).*l1.*l2.*M1.*cos(x(5)+x(6)) ...
        +(-2).*l1.*l2.*M2.*cos(x(5)+x(6))+(-4).*l1.*l2.*Mf.*cos(x(5) ...
        +x(6))+4.*l1.*l2.*M1.*cos(x(7))+8.*l1.*l2.*Mf.*cos(x(7))+( ...
        -4).*l1.*l2.*M1.*cos(x(6)+x(7))+(-8).*l1.*l2.*Mf.*cos(x(6)+ ...
        x(7))+(-2).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+(-4).*l1.^2.*Mf.* ...
        cos(x(5)+x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.* ...
        cos(x(7)+x(8))+(-4).*l2.*la.*Mf.*cos(x(6)+x(7)+x(8))+(-2).* ...
        l1.*la.*Mf.*cos(x(5)+x(6)+x(7)+x(8))),(1/4).*(4.*I1x+4.*I2x+ ...
        l1.^2.*M1+4.*l2.^2.*M1+l2.^2.*M2+4.*l1.^2.*Mf+4.*l2.^2.*Mf+ ...
        la.^2.*Mf+(-2).*l2.^2.*(2.*M1+M2+2.*Mf).*cos(x(6))+(-2).* ...
        l1.*l2.*(2.*M1+M2+2.*Mf).*cos(x(5)+x(6))+4.*l1.*l2.*M1.*cos( ...
        x(7))+8.*l1.*l2.*Mf.*cos(x(7))+(-2).*l1.*l2.*M1.*cos(x(6)+x( ...
        7))+(-4).*l1.*l2.*Mf.*cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x( ...
        5)+x(6)+x(7))+(-4).*l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+4.*l1.* ...
        la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos(x(7)+x(8))+(-2).*l2.* ...
        la.*Mf.*cos(x(6)+x(7)+x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+x(6)+ ...
        x(7)+x(8))),(1/4).*(4.*I1x+l1.^2.*M1+4.*l1.^2.*Mf+la.^2.*Mf+ ...
        2.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+(-2).*l1.*l2.*(M1+2.*Mf).* ...
        cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+(-4).* ...
        l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+2.* ...
        l2.*la.*Mf.*cos(x(7)+x(8))+(-2).*l2.*la.*Mf.*cos(x(6)+x(7)+ ...
        x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+x(6)+x(7)+x(8))),(1/4).* ...
        la.*Mf.*(la+2.*l1.*cos(x(8))+2.*l2.*cos(x(7)+x(8))+(-2).* ...
        l2.*cos(x(6)+x(7)+x(8))+(-2).*l1.*cos(x(5)+x(6)+x(7)+x(8))), ...
        l1.*cos(x(3)+x(4))+l2.*cos(x(3)+x(4)+x(5))+(-1).*l2.*cos(x( ...
        3)+x(4)+x(5)+x(6))+(-1).*l1.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+( ...
        -1).*la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),l1.*sin(x(3)+x( ...
        4))+l2.*sin(x(3)+x(4)+x(5))+(-1).*l2.*sin(x(3)+x(4)+x(5)+x( ...
        6))+(-1).*l1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+(-1).*la.*sin(x( ...
        3)+x(4)+x(5)+x(6)+x(7)+x(8))];

        FullMatrix(5,:) =[(1/2).*((-1).*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(3)+x(4)+ ...
        x(5))+l2.*(2.*M1+M2+2.*Mf).*cos(x(3)+x(4)+x(5)+x(6))+l1.* ...
        M1.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+2.*l1.*Mf.*cos(x(3)+x(4)+ ...
        x(5)+x(6)+x(7))+la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))), ...
        (1/2).*((-1).*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).*sin(x(3)+x(4)+x( ...
        5))+l2.*(2.*M1+M2+2.*Mf).*sin(x(3)+x(4)+x(5)+x(6))+l1.*M1.* ...
        sin(x(3)+x(4)+x(5)+x(6)+x(7))+2.*l1.*Mf.*sin(x(3)+x(4)+x(5)+ ...
        x(6)+x(7))+la.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))),(1/4) ...
        .*(4.*I1x+8.*I2x+4.*Ipx+l1.^2.*M1+8.*l2.^2.*M1+6.*l2.^2.*M2+ ...
        4.*l1.^2.*Mf+8.*l2.^2.*Mf+la.^2.*Mf+4.*l2.^2.*Mp+2.*l1.*l2.* ...
        (2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(5))+2.*l2.*la.*(2.*M1+3.*M2+ ...
        2.*(Mf+Mp)).*cos(x(4)+x(5))+(-8).*l2.^2.*M1.*cos(x(6))+(-4) ...
        .*l2.^2.*M2.*cos(x(6))+(-8).*l2.^2.*Mf.*cos(x(6))+(-4).*l1.* ...
        l2.*M1.*cos(x(5)+x(6))+(-2).*l1.*l2.*M2.*cos(x(5)+x(6))+(-4) ...
        .*l1.*l2.*Mf.*cos(x(5)+x(6))+(-4).*l2.*la.*M1.*cos(x(4)+x(5) ...
        +x(6))+(-2).*l2.*la.*M2.*cos(x(4)+x(5)+x(6))+(-4).*l2.*la.* ...
        Mf.*cos(x(4)+x(5)+x(6))+4.*l1.*l2.*M1.*cos(x(7))+8.*l1.*l2.* ...
        Mf.*cos(x(7))+(-4).*l1.*l2.*M1.*cos(x(6)+x(7))+(-8).*l1.* ...
        l2.*Mf.*cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+ ...
        (-4).*l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+(-2).*l1.*la.*M1.*cos( ...
        x(4)+x(5)+x(6)+x(7))+(-4).*l1.*la.*Mf.*cos(x(4)+x(5)+x(6)+x( ...
        7))+4.*l1.*la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos(x(7)+x(8))+( ...
        -4).*l2.*la.*Mf.*cos(x(6)+x(7)+x(8))+(-2).*l1.*la.*Mf.*cos( ...
        x(5)+x(6)+x(7)+x(8))+(-2).*la.^2.*Mf.*cos(x(4)+x(5)+x(6)+x( ...
        7)+x(8))),(1/4).*(4.*I1x+8.*I2x+4.*Ipx+l1.^2.*M1+8.*l2.^2.* ...
        M1+6.*l2.^2.*M2+4.*l1.^2.*Mf+8.*l2.^2.*Mf+la.^2.*Mf+4.* ...
        l2.^2.*Mp+2.*l1.*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(5))+( ...
        -4).*l2.^2.*(2.*M1+M2+2.*Mf).*cos(x(6))+(-4).*l1.*l2.*M1.* ...
        cos(x(5)+x(6))+(-2).*l1.*l2.*M2.*cos(x(5)+x(6))+(-4).*l1.* ...
        l2.*Mf.*cos(x(5)+x(6))+4.*l1.*l2.*M1.*cos(x(7))+8.*l1.*l2.* ...
        Mf.*cos(x(7))+(-4).*l1.*l2.*M1.*cos(x(6)+x(7))+(-8).*l1.* ...
        l2.*Mf.*cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+ ...
        (-4).*l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8) ...
        )+4.*l2.*la.*Mf.*cos(x(7)+x(8))+(-4).*l2.*la.*Mf.*cos(x(6)+ ...
        x(7)+x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+x(6)+x(7)+x(8))),(1/4) ...
        .*(4.*I1x+8.*I2x+4.*Ipx+l1.^2.*M1+8.*l2.^2.*M1+6.*l2.^2.*M2+ ...
        4.*l1.^2.*Mf+8.*l2.^2.*Mf+la.^2.*Mf+4.*l2.^2.*Mp+(-4).* ...
        l2.^2.*(2.*M1+M2+2.*Mf).*cos(x(6))+4.*l1.*l2.*(M1+2.*Mf).* ...
        cos(x(7))+(-4).*l1.*l2.*M1.*cos(x(6)+x(7))+(-8).*l1.*l2.* ...
        Mf.*cos(x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.* ...
        cos(x(7)+x(8))+(-4).*l2.*la.*Mf.*cos(x(6)+x(7)+x(8))),(1/4) ...
        .*(4.*I1x+4.*I2x+l1.^2.*M1+4.*l2.^2.*M1+l2.^2.*M2+4.*l1.^2.* ...
        Mf+4.*l2.^2.*Mf+la.^2.*Mf+(-2).*l2.^2.*(2.*M1+M2+2.*Mf).* ...
        cos(x(6))+4.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+(-2).*l1.*l2.* ...
        M1.*cos(x(6)+x(7))+(-4).*l1.*l2.*Mf.*cos(x(6)+x(7))+4.*l1.* ...
        la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos(x(7)+x(8))+(-2).*l2.* ...
        la.*Mf.*cos(x(6)+x(7)+x(8))),(1/4).*(4.*I1x+l1.^2.*M1+4.* ...
        l1.^2.*Mf+la.^2.*Mf+2.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+(-2).* ...
        l1.*l2.*(M1+2.*Mf).*cos(x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+ ...
        2.*l2.*la.*Mf.*cos(x(7)+x(8))+(-2).*l2.*la.*Mf.*cos(x(6)+x( ...
        7)+x(8))),(1/4).*la.*Mf.*(la+2.*l1.*cos(x(8))+2.*l2.*cos(x( ...
        7)+x(8))+(-2).*l2.*cos(x(6)+x(7)+x(8))),l2.*cos(x(3)+x(4)+x( ...
        5))+(-1).*l2.*cos(x(3)+x(4)+x(5)+x(6))+(-1).*l1.*cos(x(3)+x( ...
        4)+x(5)+x(6)+x(7))+(-1).*la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x( ...
        8)),l2.*sin(x(3)+x(4)+x(5))+(-1).*l2.*sin(x(3)+x(4)+x(5)+x( ...
        6))+(-1).*l1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+(-1).*la.*sin(x( ...
        3)+x(4)+x(5)+x(6)+x(7)+x(8))];

        FullMatrix(6,:) =[(1/2).*(l2.*(2.*M1+M2+2.*Mf).*cos(x(3)+x(4)+x(5)+x(6))+l1.* ...
        (M1+2.*Mf).*cos(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*cos(x(3)+ ...
        x(4)+x(5)+x(6)+x(7)+x(8))),(1/2).*(l2.*(2.*M1+M2+2.*Mf).* ...
        sin(x(3)+x(4)+x(5)+x(6))+l1.*(M1+2.*Mf).*sin(x(3)+x(4)+x(5)+ ...
        x(6)+x(7))+la.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))),I1x+ ...
        I2x+(1/4).*l2.*M2.*(l2+(-2).*l2.*cos(x(6))+(-2).*l1.*cos(x( ...
        5)+x(6))+(-2).*la.*cos(x(4)+x(5)+x(6)))+(-1/4).*M1.*(l1+2.* ...
        l2.*cos(x(7))).*((-1).*l1+(-2).*l2.*cos(x(7))+2.*l2.*cos(x( ...
        6)+x(7))+2.*l1.*cos(x(5)+x(6)+x(7))+2.*la.*cos(x(4)+x(5)+x( ...
        6)+x(7)))+Mf.*((1/2).*la+l1.*cos(x(8))+l2.*cos(x(7)+x(8))).* ...
        ((1/2).*la+l1.*cos(x(8))+l2.*cos(x(7)+x(8))+(-1).*l2.*cos(x( ...
        6)+x(7)+x(8))+(-1).*l1.*cos(x(5)+x(6)+x(7)+x(8))+(-1).*la.* ...
        cos(x(4)+x(5)+x(6)+x(7)+x(8)))+(-1).*l2.*M1.*sin(x(7)).*(( ...
        -1).*l2.*sin(x(7))+l2.*sin(x(6)+x(7))+l1.*sin(x(5)+x(6)+x(7) ...
        )+la.*sin(x(4)+x(5)+x(6)+x(7)))+(-1).*Mf.*(l1.*sin(x(8))+ ...
        l2.*sin(x(7)+x(8))).*((-1).*l1.*sin(x(8))+(-1).*l2.*sin(x(7) ...
        +x(8))+l2.*sin(x(6)+x(7)+x(8))+l1.*sin(x(5)+x(6)+x(7)+x(8))+ ...
        la.*sin(x(4)+x(5)+x(6)+x(7)+x(8))),(1/4).*(4.*I1x+4.*I2x+ ...
        l1.^2.*M1+4.*l2.^2.*M1+l2.^2.*M2+4.*l1.^2.*Mf+4.*l2.^2.*Mf+ ...
        la.^2.*Mf+(-2).*l2.^2.*(2.*M1+M2+2.*Mf).*cos(x(6))+(-2).* ...
        l1.*l2.*(2.*M1+M2+2.*Mf).*cos(x(5)+x(6))+4.*l1.*l2.*M1.*cos( ...
        x(7))+8.*l1.*l2.*Mf.*cos(x(7))+(-2).*l1.*l2.*M1.*cos(x(6)+x( ...
        7))+(-4).*l1.*l2.*Mf.*cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x( ...
        5)+x(6)+x(7))+(-4).*l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+4.*l1.* ...
        la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos(x(7)+x(8))+(-2).*l2.* ...
        la.*Mf.*cos(x(6)+x(7)+x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+x(6)+ ...
        x(7)+x(8))),(1/4).*(4.*I1x+4.*I2x+l1.^2.*M1+4.*l2.^2.*M1+ ...
        l2.^2.*M2+4.*l1.^2.*Mf+4.*l2.^2.*Mf+la.^2.*Mf+(-2).*l2.^2.*( ...
        2.*M1+M2+2.*Mf).*cos(x(6))+4.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+ ...
        (-2).*l1.*l2.*M1.*cos(x(6)+x(7))+(-4).*l1.*l2.*Mf.*cos(x(6)+ ...
        x(7))+4.*l1.*la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos(x(7)+x(8)) ...
        +(-2).*l2.*la.*Mf.*cos(x(6)+x(7)+x(8))),I1x+I2x+(1/4).* ...
        l1.^2.*M1+l2.^2.*M1+(1/4).*l2.^2.*M2+l1.^2.*Mf+l2.^2.*Mf+( ...
        1/4).*la.^2.*Mf+l1.*l2.*(M1+2.*Mf).*cos(x(7))+l1.*la.*Mf.* ...
        cos(x(8))+l2.*la.*Mf.*cos(x(7)+x(8)),(1/4).*(4.*I1x+l1.^2.* ...
        M1+4.*l1.^2.*Mf+la.^2.*Mf+2.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+ ...
        4.*l1.*la.*Mf.*cos(x(8))+2.*l2.*la.*Mf.*cos(x(7)+x(8))),( ...
        1/4).*la.*Mf.*(la+2.*l1.*cos(x(8))+2.*l2.*cos(x(7)+x(8))),( ...
        -1).*l2.*cos(x(3)+x(4)+x(5)+x(6))+(-1).*l1.*cos(x(3)+x(4)+x( ...
        5)+x(6)+x(7))+(-1).*la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),( ...
        -1).*l2.*sin(x(3)+x(4)+x(5)+x(6))+(-1).*l1.*sin(x(3)+x(4)+x( ...
        5)+x(6)+x(7))+(-1).*la.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))]; ...

        FullMatrix(7,:) =[(1/2).*(l1.*(M1+2.*Mf).*cos(x(3)+x(4)+x(5)+x(6)+x(7))+la.* ...
        Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))),(1/2).*(l1.*(M1+2.* ...
        Mf).*sin(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*sin(x(3)+x(4)+x( ...
        5)+x(6)+x(7)+x(8))),I1x+(-1/4).*l1.*M1.*((-1).*l1+(-2).*l2.* ...
        cos(x(7))+2.*l2.*cos(x(6)+x(7))+2.*l1.*cos(x(5)+x(6)+x(7))+ ...
        2.*la.*cos(x(4)+x(5)+x(6)+x(7)))+Mf.*((1/2).*la+l1.*cos(x(8) ...
        )).*((1/2).*la+l1.*cos(x(8))+l2.*cos(x(7)+x(8))+(-1).*l2.* ...
        cos(x(6)+x(7)+x(8))+(-1).*l1.*cos(x(5)+x(6)+x(7)+x(8))+(-1) ...
        .*la.*cos(x(4)+x(5)+x(6)+x(7)+x(8)))+(-1).*l1.*Mf.*sin(x(8)) ...
        .*((-1).*l1.*sin(x(8))+(-1).*l2.*sin(x(7)+x(8))+l2.*sin(x(6) ...
        +x(7)+x(8))+l1.*sin(x(5)+x(6)+x(7)+x(8))+la.*sin(x(4)+x(5)+ ...
        x(6)+x(7)+x(8))),(1/4).*(4.*I1x+l1.^2.*M1+4.*l1.^2.*Mf+ ...
        la.^2.*Mf+2.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+(-2).*l1.*l2.*( ...
        M1+2.*Mf).*cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x(5)+x(6)+x( ...
        7))+(-4).*l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+4.*l1.*la.*Mf.*cos( ...
        x(8))+2.*l2.*la.*Mf.*cos(x(7)+x(8))+(-2).*l2.*la.*Mf.*cos(x( ...
        6)+x(7)+x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+x(6)+x(7)+x(8))),( ...
        1/4).*(4.*I1x+l1.^2.*M1+4.*l1.^2.*Mf+la.^2.*Mf+2.*l1.*l2.*( ...
        M1+2.*Mf).*cos(x(7))+(-2).*l1.*l2.*(M1+2.*Mf).*cos(x(6)+x(7) ...
        )+4.*l1.*la.*Mf.*cos(x(8))+2.*l2.*la.*Mf.*cos(x(7)+x(8))+( ...
        -2).*l2.*la.*Mf.*cos(x(6)+x(7)+x(8))),(1/4).*(4.*I1x+l1.^2.* ...
        M1+4.*l1.^2.*Mf+la.^2.*Mf+2.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+ ...
        4.*l1.*la.*Mf.*cos(x(8))+2.*l2.*la.*Mf.*cos(x(7)+x(8))),I1x+ ...
        (1/4).*(la.^2.*Mf+l1.^2.*(M1+4.*Mf))+l1.*la.*Mf.*cos(x(8)),( ...
        1/4).*la.*Mf.*(la+2.*l1.*cos(x(8))),(-1).*l1.*cos(x(3)+x(4)+ ...
        x(5)+x(6)+x(7))+(-1).*la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)) ...
        ,(-1).*l1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+(-1).*la.*sin(x(3)+ ...
        x(4)+x(5)+x(6)+x(7)+x(8))];

        FullMatrix(8,:) =[(1/2).*la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),(1/2).* ...
        la.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),(1/2).*la.*Mf.*(( ...
        1/2).*la+l1.*cos(x(8))+l2.*cos(x(7)+x(8))+(-1).*l2.*cos(x(6) ...
        +x(7)+x(8))+(-1).*l1.*cos(x(5)+x(6)+x(7)+x(8))+(-1).*la.* ...
        cos(x(4)+x(5)+x(6)+x(7)+x(8))),(1/4).*la.*Mf.*(la+2.*l1.* ...
        cos(x(8))+2.*l2.*cos(x(7)+x(8))+(-2).*l2.*cos(x(6)+x(7)+x(8) ...
        )+(-2).*l1.*cos(x(5)+x(6)+x(7)+x(8))),(1/4).*la.*Mf.*(la+2.* ...
        l1.*cos(x(8))+2.*l2.*cos(x(7)+x(8))+(-2).*l2.*cos(x(6)+x(7)+ ...
        x(8))),(1/4).*la.*Mf.*(la+2.*l1.*cos(x(8))+2.*l2.*cos(x(7)+ ...
        x(8))),(1/4).*la.*Mf.*(la+2.*l1.*cos(x(8))),(1/4).*la.^2.* ...
        Mf,(-1).*la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),(-1).*la.* ...
        sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))];

        FullMatrix(9,:) =[1,0,(-1).*la.*cos(x(3))+(-1).*l1.*cos(x(3)+x(4))+(-1).*l2.* ...
        cos(x(3)+x(4)+x(5))+l2.*cos(x(3)+x(4)+x(5)+x(6))+l1.*cos(x( ...
        3)+x(4)+x(5)+x(6)+x(7))+la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x( ...
        8)),(-1).*l1.*cos(x(3)+x(4))+(-1).*l2.*cos(x(3)+x(4)+x(5))+ ...
        l2.*cos(x(3)+x(4)+x(5)+x(6))+l1.*cos(x(3)+x(4)+x(5)+x(6)+x( ...
        7))+la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),(-1).*l2.*cos(x( ...
        3)+x(4)+x(5))+l2.*cos(x(3)+x(4)+x(5)+x(6))+l1.*cos(x(3)+x(4) ...
        +x(5)+x(6)+x(7))+la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),l2.* ...
        cos(x(3)+x(4)+x(5)+x(6))+l1.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+ ...
        la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),l1.*cos(x(3)+x(4)+x( ...
        5)+x(6)+x(7))+la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),la.* ...
        cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),0,0];

        FullMatrix(10,:) =[0,1,(-1).*la.*sin(x(3))+(-1).*l1.*sin(x(3)+x(4))+(-1).*l2.* ...
        sin(x(3)+x(4)+x(5))+l2.*sin(x(3)+x(4)+x(5)+x(6))+l1.*sin(x( ...
        3)+x(4)+x(5)+x(6)+x(7))+la.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x( ...
        8)),(-1).*l1.*sin(x(3)+x(4))+(-1).*l2.*sin(x(3)+x(4)+x(5))+ ...
        l2.*sin(x(3)+x(4)+x(5)+x(6))+l1.*sin(x(3)+x(4)+x(5)+x(6)+x( ...
        7))+la.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),(-1).*l2.*sin(x( ...
        3)+x(4)+x(5))+l2.*sin(x(3)+x(4)+x(5)+x(6))+l1.*sin(x(3)+x(4) ...
        +x(5)+x(6)+x(7))+la.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),l2.* ...
        sin(x(3)+x(4)+x(5)+x(6))+l1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+ ...
        la.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),l1.*sin(x(3)+x(4)+x( ...
        5)+x(6)+x(7))+la.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),la.* ...
        sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)),0,0];


        DMatrix = [(1/2).*(2.*(2.*M1+2.*M2+2.*Mf+Mp).*x(9)+(-1).*(la.*(4.*M1+ ...
        4.*M2+3.*Mf+2.*Mp).*cos(x(3))+l1.*(3.*M1+2.*(2.*M2+Mf+Mp)).* ...
        cos(x(3)+x(4))+2.*l2.*M1.*cos(x(3)+x(4)+x(5))+3.*l2.*M2.* ...
        cos(x(3)+x(4)+x(5))+2.*l2.*Mf.*cos(x(3)+x(4)+x(5))+2.*l2.* ...
        Mp.*cos(x(3)+x(4)+x(5))+(-2).*l2.*M1.*cos(x(3)+x(4)+x(5)+x( ...
        6))+(-1).*l2.*M2.*cos(x(3)+x(4)+x(5)+x(6))+(-2).*l2.*Mf.* ...
        cos(x(3)+x(4)+x(5)+x(6))+(-1).*l1.*M1.*cos(x(3)+x(4)+x(5)+x( ...
        6)+x(7))+(-2).*l1.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+(-1).* ...
        la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))).*x(11)+(-3).* ...
        l1.*M1.*cos(x(3)+x(4)).*x(12)+(-4).*l1.*M2.*cos(x(3)+x(4)).* ...
        x(12)+(-2).*l1.*Mf.*cos(x(3)+x(4)).*x(12)+(-2).*l1.*Mp.*cos( ...
        x(3)+x(4)).*x(12)+(-2).*l2.*M1.*cos(x(3)+x(4)+x(5)).*x(12)+( ...
        -3).*l2.*M2.*cos(x(3)+x(4)+x(5)).*x(12)+(-2).*l2.*Mf.*cos(x( ...
        3)+x(4)+x(5)).*x(12)+(-2).*l2.*Mp.*cos(x(3)+x(4)+x(5)).*x( ...
        12)+2.*l2.*M1.*cos(x(3)+x(4)+x(5)+x(6)).*x(12)+l2.*M2.*cos( ...
        x(3)+x(4)+x(5)+x(6)).*x(12)+2.*l2.*Mf.*cos(x(3)+x(4)+x(5)+x( ...
        6)).*x(12)+l1.*M1.*cos(x(3)+x(4)+x(5)+x(6)+x(7)).*x(12)+2.* ...
        l1.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)).*x(12)+la.*Mf.*cos(x( ...
        3)+x(4)+x(5)+x(6)+x(7)+x(8)).*x(12)+(-2).*l2.*M1.*cos(x(3)+ ...
        x(4)+x(5)).*x(13)+(-3).*l2.*M2.*cos(x(3)+x(4)+x(5)).*x(13)+( ...
        -2).*l2.*Mf.*cos(x(3)+x(4)+x(5)).*x(13)+(-2).*l2.*Mp.*cos(x( ...
        3)+x(4)+x(5)).*x(13)+2.*l2.*M1.*cos(x(3)+x(4)+x(5)+x(6)).*x( ...
        13)+l2.*M2.*cos(x(3)+x(4)+x(5)+x(6)).*x(13)+2.*l2.*Mf.*cos( ...
        x(3)+x(4)+x(5)+x(6)).*x(13)+l1.*M1.*cos(x(3)+x(4)+x(5)+x(6)+ ...
        x(7)).*x(13)+2.*l1.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)).*x(13) ...
        +la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)).*x(13)+2.*l2.* ...
        M1.*cos(x(3)+x(4)+x(5)+x(6)).*x(14)+l2.*M2.*cos(x(3)+x(4)+x( ...
        5)+x(6)).*x(14)+2.*l2.*Mf.*cos(x(3)+x(4)+x(5)+x(6)).*x(14)+ ...
        l1.*M1.*cos(x(3)+x(4)+x(5)+x(6)+x(7)).*x(14)+2.*l1.*Mf.*cos( ...
        x(3)+x(4)+x(5)+x(6)+x(7)).*x(14)+la.*Mf.*cos(x(3)+x(4)+x(5)+ ...
        x(6)+x(7)+x(8)).*x(14)+l1.*M1.*cos(x(3)+x(4)+x(5)+x(6)+x(7)) ...
        .*x(15)+2.*l1.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)).*x(15)+la.* ...
        Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)).*x(15)+la.*Mf.*cos(x( ...
        3)+x(4)+x(5)+x(6)+x(7)+x(8)).*x(16));(1/2).*(2.*(2.*M1+2.* ...
        M2+2.*Mf+Mp).*x(10)+(-1).*(la.*(4.*M1+4.*M2+3.*Mf+2.*Mp).* ...
        sin(x(3))+l1.*(3.*M1+2.*(2.*M2+Mf+Mp)).*sin(x(3)+x(4))+2.* ...
        l2.*M1.*sin(x(3)+x(4)+x(5))+3.*l2.*M2.*sin(x(3)+x(4)+x(5))+ ...
        2.*l2.*Mf.*sin(x(3)+x(4)+x(5))+2.*l2.*Mp.*sin(x(3)+x(4)+x(5) ...
        )+(-2).*l2.*M1.*sin(x(3)+x(4)+x(5)+x(6))+(-1).*l2.*M2.*sin( ...
        x(3)+x(4)+x(5)+x(6))+(-2).*l2.*Mf.*sin(x(3)+x(4)+x(5)+x(6))+ ...
        (-1).*l1.*M1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+(-2).*l1.*Mf.* ...
        sin(x(3)+x(4)+x(5)+x(6)+x(7))+(-1).*la.*Mf.*sin(x(3)+x(4)+x( ...
        5)+x(6)+x(7)+x(8))).*x(11)+(-3).*l1.*M1.*sin(x(3)+x(4)).*x( ...
        12)+(-4).*l1.*M2.*sin(x(3)+x(4)).*x(12)+(-2).*l1.*Mf.*sin(x( ...
        3)+x(4)).*x(12)+(-2).*l1.*Mp.*sin(x(3)+x(4)).*x(12)+(-2).* ...
        l2.*M1.*sin(x(3)+x(4)+x(5)).*x(12)+(-3).*l2.*M2.*sin(x(3)+x( ...
        4)+x(5)).*x(12)+(-2).*l2.*Mf.*sin(x(3)+x(4)+x(5)).*x(12)+( ...
        -2).*l2.*Mp.*sin(x(3)+x(4)+x(5)).*x(12)+2.*l2.*M1.*sin(x(3)+ ...
        x(4)+x(5)+x(6)).*x(12)+l2.*M2.*sin(x(3)+x(4)+x(5)+x(6)).*x( ...
        12)+2.*l2.*Mf.*sin(x(3)+x(4)+x(5)+x(6)).*x(12)+l1.*M1.*sin( ...
        x(3)+x(4)+x(5)+x(6)+x(7)).*x(12)+2.*l1.*Mf.*sin(x(3)+x(4)+x( ...
        5)+x(6)+x(7)).*x(12)+la.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x( ...
        8)).*x(12)+(-2).*l2.*M1.*sin(x(3)+x(4)+x(5)).*x(13)+(-3).* ...
        l2.*M2.*sin(x(3)+x(4)+x(5)).*x(13)+(-2).*l2.*Mf.*sin(x(3)+x( ...
        4)+x(5)).*x(13)+(-2).*l2.*Mp.*sin(x(3)+x(4)+x(5)).*x(13)+2.* ...
        l2.*M1.*sin(x(3)+x(4)+x(5)+x(6)).*x(13)+l2.*M2.*sin(x(3)+x( ...
        4)+x(5)+x(6)).*x(13)+2.*l2.*Mf.*sin(x(3)+x(4)+x(5)+x(6)).*x( ...
        13)+l1.*M1.*sin(x(3)+x(4)+x(5)+x(6)+x(7)).*x(13)+2.*l1.*Mf.* ...
        sin(x(3)+x(4)+x(5)+x(6)+x(7)).*x(13)+la.*Mf.*sin(x(3)+x(4)+ ...
        x(5)+x(6)+x(7)+x(8)).*x(13)+2.*l2.*M1.*sin(x(3)+x(4)+x(5)+x( ...
        6)).*x(14)+l2.*M2.*sin(x(3)+x(4)+x(5)+x(6)).*x(14)+2.*l2.* ...
        Mf.*sin(x(3)+x(4)+x(5)+x(6)).*x(14)+l1.*M1.*sin(x(3)+x(4)+x( ...
        5)+x(6)+x(7)).*x(14)+2.*l1.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7) ...
        ).*x(14)+la.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)).*x(14)+ ...
        l1.*M1.*sin(x(3)+x(4)+x(5)+x(6)+x(7)).*x(15)+2.*l1.*Mf.*sin( ...
        x(3)+x(4)+x(5)+x(6)+x(7)).*x(15)+la.*Mf.*sin(x(3)+x(4)+x(5)+ ...
        x(6)+x(7)+x(8)).*x(15)+la.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+ ...
        x(8)).*x(16));(1/4).*((-2).*(la.*(4.*M1+4.*M2+3.*Mf+2.*Mp).* ...
        cos(x(3))+l1.*(3.*M1+2.*(2.*M2+Mf+Mp)).*cos(x(3)+x(4))+2.* ...
        l2.*M1.*cos(x(3)+x(4)+x(5))+3.*l2.*M2.*cos(x(3)+x(4)+x(5))+ ...
        2.*l2.*Mf.*cos(x(3)+x(4)+x(5))+2.*l2.*Mp.*cos(x(3)+x(4)+x(5) ...
        )+(-2).*l2.*M1.*cos(x(3)+x(4)+x(5)+x(6))+(-1).*l2.*M2.*cos( ...
        x(3)+x(4)+x(5)+x(6))+(-2).*l2.*Mf.*cos(x(3)+x(4)+x(5)+x(6))+ ...
        (-1).*l1.*M1.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+(-2).*l1.*Mf.* ...
        cos(x(3)+x(4)+x(5)+x(6)+x(7))+(-1).*la.*Mf.*cos(x(3)+x(4)+x( ...
        5)+x(6)+x(7)+x(8))).*x(9)+(-2).*(la.*(4.*M1+4.*M2+3.*Mf+2.* ...
        Mp).*sin(x(3))+l1.*(3.*M1+2.*(2.*M2+Mf+Mp)).*sin(x(3)+x(4))+ ...
        2.*l2.*M1.*sin(x(3)+x(4)+x(5))+3.*l2.*M2.*sin(x(3)+x(4)+x(5) ...
        )+2.*l2.*Mf.*sin(x(3)+x(4)+x(5))+2.*l2.*Mp.*sin(x(3)+x(4)+x( ...
        5))+(-2).*l2.*M1.*sin(x(3)+x(4)+x(5)+x(6))+(-1).*l2.*M2.* ...
        sin(x(3)+x(4)+x(5)+x(6))+(-2).*l2.*Mf.*sin(x(3)+x(4)+x(5)+x( ...
        6))+(-1).*l1.*M1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+(-2).*l1.* ...
        Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+(-1).*la.*Mf.*sin(x(3)+x( ...
        4)+x(5)+x(6)+x(7)+x(8))).*x(10)+4.*(2.*I1x+2.*I2x+Ipx+(1/4) ...
        .*la.^2.*Mf+(1/4).*M1.*(l1+2.*la.*cos(x(4))).^2+Mp.*(l2+l1.* ...
        cos(x(5))+la.*cos(x(4)+x(5))).^2+(1/4).*M2.*(l2+2.*l1.*cos( ...
        x(5))+2.*la.*cos(x(4)+x(5))).^2+(1/4).*M2.*(l2+(-2).*l2.* ...
        cos(x(6))+(-2).*l1.*cos(x(5)+x(6))+(-2).*la.*cos(x(4)+x(5)+ ...
        x(6))).^2+M1.*((-1/2).*l1+(-1).*l2.*cos(x(7))+l2.*cos(x(6)+ ...
        x(7))+l1.*cos(x(5)+x(6)+x(7))+la.*cos(x(4)+x(5)+x(6)+x(7))) ...
        .^2+Mf.*((-1/2).*la+(-1).*l1.*cos(x(8))+(-1).*l2.*cos(x(7)+ ...
        x(8))+l2.*cos(x(6)+x(7)+x(8))+l1.*cos(x(5)+x(6)+x(7)+x(8))+ ...
        la.*cos(x(4)+x(5)+x(6)+x(7)+x(8))).^2+la.^2.*M1.*sin(x(4)) ...
        .^2+M2.*(l1.*sin(x(5))+la.*sin(x(4)+x(5))).^2+Mp.*(l1.*sin( ...
        x(5))+la.*sin(x(4)+x(5))).^2+M2.*(l2.*sin(x(6))+l1.*sin(x(5) ...
        +x(6))+la.*sin(x(4)+x(5)+x(6))).^2+M1.*((-1).*l2.*sin(x(7))+ ...
        l2.*sin(x(6)+x(7))+l1.*sin(x(5)+x(6)+x(7))+la.*sin(x(4)+x(5) ...
        +x(6)+x(7))).^2+Mf.*((-1).*l1.*sin(x(8))+(-1).*l2.*sin(x(7)+ ...
        x(8))+l2.*sin(x(6)+x(7)+x(8))+l1.*sin(x(5)+x(6)+x(7)+x(8))+ ...
        la.*sin(x(4)+x(5)+x(6)+x(7)+x(8))).^2).*x(11)+(8.*I1x+8.* ...
        I2x+4.*Ipx+6.*l1.^2.*M1+8.*l2.^2.*M1+8.*l1.^2.*M2+6.*l2.^2.* ...
        M2+8.*l1.^2.*Mf+8.*l2.^2.*Mf+la.^2.*Mf+4.*l1.^2.*Mp+4.* ...
        l2.^2.*Mp+2.*l1.*la.*(3.*M1+2.*(2.*M2+Mf+Mp)).*cos(x(4))+4.* ...
        l1.*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(5))+4.*l2.*la.*M1.* ...
        cos(x(4)+x(5))+6.*l2.*la.*M2.*cos(x(4)+x(5))+4.*l2.*la.*Mf.* ...
        cos(x(4)+x(5))+4.*l2.*la.*Mp.*cos(x(4)+x(5))+(-8).*l2.^2.* ...
        M1.*cos(x(6))+(-4).*l2.^2.*M2.*cos(x(6))+(-8).*l2.^2.*Mf.* ...
        cos(x(6))+(-8).*l1.*l2.*M1.*cos(x(5)+x(6))+(-4).*l1.*l2.* ...
        M2.*cos(x(5)+x(6))+(-8).*l1.*l2.*Mf.*cos(x(5)+x(6))+(-4).* ...
        l2.*la.*M1.*cos(x(4)+x(5)+x(6))+(-2).*l2.*la.*M2.*cos(x(4)+ ...
        x(5)+x(6))+(-4).*l2.*la.*Mf.*cos(x(4)+x(5)+x(6))+4.*l1.*l2.* ...
        M1.*cos(x(7))+8.*l1.*l2.*Mf.*cos(x(7))+(-4).*l1.*l2.*M1.* ...
        cos(x(6)+x(7))+(-8).*l1.*l2.*Mf.*cos(x(6)+x(7))+(-4).* ...
        l1.^2.*M1.*cos(x(5)+x(6)+x(7))+(-8).*l1.^2.*Mf.*cos(x(5)+x( ...
        6)+x(7))+(-2).*l1.*la.*M1.*cos(x(4)+x(5)+x(6)+x(7))+(-4).* ...
        l1.*la.*Mf.*cos(x(4)+x(5)+x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8) ...
        )+4.*l2.*la.*Mf.*cos(x(7)+x(8))+(-4).*l2.*la.*Mf.*cos(x(6)+ ...
        x(7)+x(8))+(-4).*l1.*la.*Mf.*cos(x(5)+x(6)+x(7)+x(8))+(-2).* ...
        la.^2.*Mf.*cos(x(4)+x(5)+x(6)+x(7)+x(8))).*x(12)+(4.*I1x+8.* ...
        I2x+4.*Ipx+l1.^2.*M1+8.*l2.^2.*M1+6.*l2.^2.*M2+4.*l1.^2.*Mf+ ...
        8.*l2.^2.*Mf+la.^2.*Mf+4.*l2.^2.*Mp+2.*l1.*l2.*(2.*M1+3.*M2+ ...
        2.*(Mf+Mp)).*cos(x(5))+2.*l2.*la.*(2.*M1+3.*M2+2.*(Mf+Mp)).* ...
        cos(x(4)+x(5))+(-8).*l2.^2.*M1.*cos(x(6))+(-4).*l2.^2.*M2.* ...
        cos(x(6))+(-8).*l2.^2.*Mf.*cos(x(6))+(-4).*l1.*l2.*M1.*cos( ...
        x(5)+x(6))+(-2).*l1.*l2.*M2.*cos(x(5)+x(6))+(-4).*l1.*l2.* ...
        Mf.*cos(x(5)+x(6))+(-4).*l2.*la.*M1.*cos(x(4)+x(5)+x(6))+( ...
        -2).*l2.*la.*M2.*cos(x(4)+x(5)+x(6))+(-4).*l2.*la.*Mf.*cos( ...
        x(4)+x(5)+x(6))+4.*l1.*l2.*M1.*cos(x(7))+8.*l1.*l2.*Mf.*cos( ...
        x(7))+(-4).*l1.*l2.*M1.*cos(x(6)+x(7))+(-8).*l1.*l2.*Mf.* ...
        cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+(-4).* ...
        l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+(-2).*l1.*la.*M1.*cos(x(4)+x( ...
        5)+x(6)+x(7))+(-4).*l1.*la.*Mf.*cos(x(4)+x(5)+x(6)+x(7))+4.* ...
        l1.*la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos(x(7)+x(8))+(-4).* ...
        l2.*la.*Mf.*cos(x(6)+x(7)+x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+ ...
        x(6)+x(7)+x(8))+(-2).*la.^2.*Mf.*cos(x(4)+x(5)+x(6)+x(7)+x( ...
        8))).*x(13)+4.*(I1x+I2x+(1/4).*l2.*M2.*(l2+(-2).*l2.*cos(x( ...
        6))+(-2).*l1.*cos(x(5)+x(6))+(-2).*la.*cos(x(4)+x(5)+x(6)))+ ...
        (-1/4).*M1.*(l1+2.*l2.*cos(x(7))).*((-1).*l1+(-2).*l2.*cos( ...
        x(7))+2.*l2.*cos(x(6)+x(7))+2.*l1.*cos(x(5)+x(6)+x(7))+2.* ...
        la.*cos(x(4)+x(5)+x(6)+x(7)))+Mf.*((1/2).*la+l1.*cos(x(8))+ ...
        l2.*cos(x(7)+x(8))).*((1/2).*la+l1.*cos(x(8))+l2.*cos(x(7)+ ...
        x(8))+(-1).*l2.*cos(x(6)+x(7)+x(8))+(-1).*l1.*cos(x(5)+x(6)+ ...
        x(7)+x(8))+(-1).*la.*cos(x(4)+x(5)+x(6)+x(7)+x(8)))+(-1).* ...
        l2.*M1.*sin(x(7)).*((-1).*l2.*sin(x(7))+l2.*sin(x(6)+x(7))+ ...
        l1.*sin(x(5)+x(6)+x(7))+la.*sin(x(4)+x(5)+x(6)+x(7)))+(-1).* ...
        Mf.*(l1.*sin(x(8))+l2.*sin(x(7)+x(8))).*((-1).*l1.*sin(x(8)) ...
        +(-1).*l2.*sin(x(7)+x(8))+l2.*sin(x(6)+x(7)+x(8))+l1.*sin(x( ...
        5)+x(6)+x(7)+x(8))+la.*sin(x(4)+x(5)+x(6)+x(7)+x(8)))).*x( ...
        14)+(4.*I1x+l1.^2.*M1+4.*l1.^2.*Mf+la.^2.*Mf+2.*l1.*l2.*(M1+ ...
        2.*Mf).*cos(x(7))+(-2).*l1.*l2.*(M1+2.*Mf).*cos(x(6)+x(7))+( ...
        -2).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+(-4).*l1.^2.*Mf.*cos(x( ...
        5)+x(6)+x(7))+(-2).*l1.*la.*M1.*cos(x(4)+x(5)+x(6)+x(7))+( ...
        -4).*l1.*la.*Mf.*cos(x(4)+x(5)+x(6)+x(7))+4.*l1.*la.*Mf.* ...
        cos(x(8))+2.*l2.*la.*Mf.*cos(x(7)+x(8))+(-2).*l2.*la.*Mf.* ...
        cos(x(6)+x(7)+x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+x(6)+x(7)+x( ...
        8))+(-2).*la.^2.*Mf.*cos(x(4)+x(5)+x(6)+x(7)+x(8))).*x(15)+ ...
        2.*la.*Mf.*((1/2).*la+l1.*cos(x(8))+l2.*cos(x(7)+x(8))+(-1) ...
        .*l2.*cos(x(6)+x(7)+x(8))+(-1).*l1.*cos(x(5)+x(6)+x(7)+x(8)) ...
        +(-1).*la.*cos(x(4)+x(5)+x(6)+x(7)+x(8))).*x(16));(1/4).*( ...
        2.*((-1).*l1.*(3.*M1+2.*(2.*M2+Mf+Mp)).*cos(x(3)+x(4))+(-1) ...
        .*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(3)+x(4)+x(5))+2.*l2.* ...
        M1.*cos(x(3)+x(4)+x(5)+x(6))+l2.*M2.*cos(x(3)+x(4)+x(5)+x(6) ...
        )+2.*l2.*Mf.*cos(x(3)+x(4)+x(5)+x(6))+l1.*M1.*cos(x(3)+x(4)+ ...
        x(5)+x(6)+x(7))+2.*l1.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+ ...
        la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))).*x(9)+2.*((-1).* ...
        l1.*(3.*M1+2.*(2.*M2+Mf+Mp)).*sin(x(3)+x(4))+(-1).*l2.*(2.* ...
        M1+3.*M2+2.*(Mf+Mp)).*sin(x(3)+x(4)+x(5))+2.*l2.*M1.*sin(x( ...
        3)+x(4)+x(5)+x(6))+l2.*M2.*sin(x(3)+x(4)+x(5)+x(6))+2.*l2.* ...
        Mf.*sin(x(3)+x(4)+x(5)+x(6))+l1.*M1.*sin(x(3)+x(4)+x(5)+x(6) ...
        +x(7))+2.*l1.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*sin( ...
        x(3)+x(4)+x(5)+x(6)+x(7)+x(8))).*x(10)+(8.*I1x+8.*I2x+4.* ...
        Ipx+6.*l1.^2.*M1+8.*l2.^2.*M1+8.*l1.^2.*M2+6.*l2.^2.*M2+8.* ...
        l1.^2.*Mf+8.*l2.^2.*Mf+la.^2.*Mf+4.*l1.^2.*Mp+4.*l2.^2.*Mp+ ...
        2.*l1.*la.*(3.*M1+2.*(2.*M2+Mf+Mp)).*cos(x(4))+4.*l1.*l2.*( ...
        2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(5))+4.*l2.*la.*M1.*cos(x(4)+ ...
        x(5))+6.*l2.*la.*M2.*cos(x(4)+x(5))+4.*l2.*la.*Mf.*cos(x(4)+ ...
        x(5))+4.*l2.*la.*Mp.*cos(x(4)+x(5))+(-8).*l2.^2.*M1.*cos(x( ...
        6))+(-4).*l2.^2.*M2.*cos(x(6))+(-8).*l2.^2.*Mf.*cos(x(6))+( ...
        -8).*l1.*l2.*M1.*cos(x(5)+x(6))+(-4).*l1.*l2.*M2.*cos(x(5)+ ...
        x(6))+(-8).*l1.*l2.*Mf.*cos(x(5)+x(6))+(-4).*l2.*la.*M1.* ...
        cos(x(4)+x(5)+x(6))+(-2).*l2.*la.*M2.*cos(x(4)+x(5)+x(6))+( ...
        -4).*l2.*la.*Mf.*cos(x(4)+x(5)+x(6))+4.*l1.*l2.*M1.*cos(x(7) ...
        )+8.*l1.*l2.*Mf.*cos(x(7))+(-4).*l1.*l2.*M1.*cos(x(6)+x(7))+ ...
        (-8).*l1.*l2.*Mf.*cos(x(6)+x(7))+(-4).*l1.^2.*M1.*cos(x(5)+ ...
        x(6)+x(7))+(-8).*l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+(-2).*l1.* ...
        la.*M1.*cos(x(4)+x(5)+x(6)+x(7))+(-4).*l1.*la.*Mf.*cos(x(4)+ ...
        x(5)+x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos( ...
        x(7)+x(8))+(-4).*l2.*la.*Mf.*cos(x(6)+x(7)+x(8))+(-4).*l1.* ...
        la.*Mf.*cos(x(5)+x(6)+x(7)+x(8))+(-2).*la.^2.*Mf.*cos(x(4)+ ...
        x(5)+x(6)+x(7)+x(8))).*x(11)+4.*(2.*I1x+2.*I2x+Ipx+(1/4).* ...
        l1.^2.*M1+Mp.*(l2+l1.*cos(x(5))).^2+(1/4).*M2.*(l2+2.*l1.* ...
        cos(x(5))).^2+(1/4).*M2.*(l2+(-2).*l2.*cos(x(6))+(-2).*l1.* ...
        cos(x(5)+x(6))).^2+M1.*((-1/2).*l1+(-1).*l2.*cos(x(7))+l2.* ...
        cos(x(6)+x(7))+l1.*cos(x(5)+x(6)+x(7))).^2+Mf.*((1/2).*la+ ...
        l1.*cos(x(8))+l2.*cos(x(7)+x(8))+(-1).*l2.*cos(x(6)+x(7)+x( ...
        8))+(-1).*l1.*cos(x(5)+x(6)+x(7)+x(8))).^2+l1.^2.*M2.*sin(x( ...
        5)).^2+l1.^2.*Mp.*sin(x(5)).^2+M2.*(l2.*sin(x(6))+l1.*sin(x( ...
        5)+x(6))).^2+M1.*((-1).*l2.*sin(x(7))+l2.*sin(x(6)+x(7))+ ...
        l1.*sin(x(5)+x(6)+x(7))).^2+Mf.*(l1.*sin(x(8))+l2.*sin(x(7)+ ...
        x(8))+(-1).*l2.*sin(x(6)+x(7)+x(8))+(-1).*l1.*sin(x(5)+x(6)+ ...
        x(7)+x(8))).^2).*x(12)+(4.*I1x+8.*I2x+4.*Ipx+l1.^2.*M1+8.* ...
        l2.^2.*M1+6.*l2.^2.*M2+4.*l1.^2.*Mf+8.*l2.^2.*Mf+la.^2.*Mf+ ...
        4.*l2.^2.*Mp+2.*l1.*l2.*(2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(5))+ ...
        (-4).*l2.^2.*(2.*M1+M2+2.*Mf).*cos(x(6))+(-4).*l1.*l2.*M1.* ...
        cos(x(5)+x(6))+(-2).*l1.*l2.*M2.*cos(x(5)+x(6))+(-4).*l1.* ...
        l2.*Mf.*cos(x(5)+x(6))+4.*l1.*l2.*M1.*cos(x(7))+8.*l1.*l2.* ...
        Mf.*cos(x(7))+(-4).*l1.*l2.*M1.*cos(x(6)+x(7))+(-8).*l1.* ...
        l2.*Mf.*cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+ ...
        (-4).*l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8) ...
        )+4.*l2.*la.*Mf.*cos(x(7)+x(8))+(-4).*l2.*la.*Mf.*cos(x(6)+ ...
        x(7)+x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+x(6)+x(7)+x(8))).*x( ...
        13)+(4.*I1x+4.*I2x+l1.^2.*M1+4.*l2.^2.*M1+l2.^2.*M2+4.* ...
        l1.^2.*Mf+4.*l2.^2.*Mf+la.^2.*Mf+(-2).*l2.^2.*(2.*M1+M2+2.* ...
        Mf).*cos(x(6))+(-2).*l1.*l2.*(2.*M1+M2+2.*Mf).*cos(x(5)+x(6) ...
        )+4.*l1.*l2.*M1.*cos(x(7))+8.*l1.*l2.*Mf.*cos(x(7))+(-2).* ...
        l1.*l2.*M1.*cos(x(6)+x(7))+(-4).*l1.*l2.*Mf.*cos(x(6)+x(7))+ ...
        (-2).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+(-4).*l1.^2.*Mf.*cos(x( ...
        5)+x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos(x( ...
        7)+x(8))+(-2).*l2.*la.*Mf.*cos(x(6)+x(7)+x(8))+(-2).*l1.* ...
        la.*Mf.*cos(x(5)+x(6)+x(7)+x(8))).*x(14)+(4.*I1x+l1.^2.*M1+ ...
        4.*l1.^2.*Mf+la.^2.*Mf+2.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+(-2) ...
        .*l1.*l2.*(M1+2.*Mf).*cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x( ...
        5)+x(6)+x(7))+(-4).*l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+4.*l1.* ...
        la.*Mf.*cos(x(8))+2.*l2.*la.*Mf.*cos(x(7)+x(8))+(-2).*l2.* ...
        la.*Mf.*cos(x(6)+x(7)+x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+x(6)+ ...
        x(7)+x(8))).*x(15)+la.*Mf.*(la+2.*l1.*cos(x(8))+2.*l2.*cos( ...
        x(7)+x(8))+(-2).*l2.*cos(x(6)+x(7)+x(8))+(-2).*l1.*cos(x(5)+ ...
        x(6)+x(7)+x(8))).*x(16));(1/4).*(2.*((-1).*l2.*(2.*M1+3.*M2+ ...
        2.*(Mf+Mp)).*cos(x(3)+x(4)+x(5))+l2.*(2.*M1+M2+2.*Mf).*cos( ...
        x(3)+x(4)+x(5)+x(6))+l1.*M1.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+ ...
        2.*l1.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*cos(x(3)+x( ...
        4)+x(5)+x(6)+x(7)+x(8))).*x(9)+2.*((-1).*l2.*(2.*M1+3.*M2+ ...
        2.*(Mf+Mp)).*sin(x(3)+x(4)+x(5))+l2.*(2.*M1+M2+2.*Mf).*sin( ...
        x(3)+x(4)+x(5)+x(6))+l1.*M1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+ ...
        2.*l1.*Mf.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*sin(x(3)+x( ...
        4)+x(5)+x(6)+x(7)+x(8))).*x(10)+(4.*I1x+8.*I2x+4.*Ipx+ ...
        l1.^2.*M1+8.*l2.^2.*M1+6.*l2.^2.*M2+4.*l1.^2.*Mf+8.*l2.^2.* ...
        Mf+la.^2.*Mf+4.*l2.^2.*Mp+2.*l1.*l2.*(2.*M1+3.*M2+2.*(Mf+Mp) ...
        ).*cos(x(5))+2.*l2.*la.*(2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(4)+ ...
        x(5))+(-8).*l2.^2.*M1.*cos(x(6))+(-4).*l2.^2.*M2.*cos(x(6))+ ...
        (-8).*l2.^2.*Mf.*cos(x(6))+(-4).*l1.*l2.*M1.*cos(x(5)+x(6))+ ...
        (-2).*l1.*l2.*M2.*cos(x(5)+x(6))+(-4).*l1.*l2.*Mf.*cos(x(5)+ ...
        x(6))+(-4).*l2.*la.*M1.*cos(x(4)+x(5)+x(6))+(-2).*l2.*la.* ...
        M2.*cos(x(4)+x(5)+x(6))+(-4).*l2.*la.*Mf.*cos(x(4)+x(5)+x(6) ...
        )+4.*l1.*l2.*M1.*cos(x(7))+8.*l1.*l2.*Mf.*cos(x(7))+(-4).* ...
        l1.*l2.*M1.*cos(x(6)+x(7))+(-8).*l1.*l2.*Mf.*cos(x(6)+x(7))+ ...
        (-2).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+(-4).*l1.^2.*Mf.*cos(x( ...
        5)+x(6)+x(7))+(-2).*l1.*la.*M1.*cos(x(4)+x(5)+x(6)+x(7))+( ...
        -4).*l1.*la.*Mf.*cos(x(4)+x(5)+x(6)+x(7))+4.*l1.*la.*Mf.* ...
        cos(x(8))+4.*l2.*la.*Mf.*cos(x(7)+x(8))+(-4).*l2.*la.*Mf.* ...
        cos(x(6)+x(7)+x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+x(6)+x(7)+x( ...
        8))+(-2).*la.^2.*Mf.*cos(x(4)+x(5)+x(6)+x(7)+x(8))).*x(11)+( ...
        4.*I1x+8.*I2x+4.*Ipx+l1.^2.*M1+8.*l2.^2.*M1+6.*l2.^2.*M2+4.* ...
        l1.^2.*Mf+8.*l2.^2.*Mf+la.^2.*Mf+4.*l2.^2.*Mp+2.*l1.*l2.*( ...
        2.*M1+3.*M2+2.*(Mf+Mp)).*cos(x(5))+(-4).*l2.^2.*(2.*M1+M2+ ...
        2.*Mf).*cos(x(6))+(-4).*l1.*l2.*M1.*cos(x(5)+x(6))+(-2).* ...
        l1.*l2.*M2.*cos(x(5)+x(6))+(-4).*l1.*l2.*Mf.*cos(x(5)+x(6))+ ...
        4.*l1.*l2.*M1.*cos(x(7))+8.*l1.*l2.*Mf.*cos(x(7))+(-4).*l1.* ...
        l2.*M1.*cos(x(6)+x(7))+(-8).*l1.*l2.*Mf.*cos(x(6)+x(7))+(-2) ...
        .*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+(-4).*l1.^2.*Mf.*cos(x(5)+ ...
        x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos(x(7)+ ...
        x(8))+(-4).*l2.*la.*Mf.*cos(x(6)+x(7)+x(8))+(-2).*l1.*la.* ...
        Mf.*cos(x(5)+x(6)+x(7)+x(8))).*x(12)+(4.*I1x+8.*I2x+4.*Ipx+ ...
        l1.^2.*M1+8.*l2.^2.*M1+6.*l2.^2.*M2+4.*l1.^2.*Mf+8.*l2.^2.* ...
        Mf+la.^2.*Mf+4.*l2.^2.*Mp+(-4).*l2.^2.*(2.*M1+M2+2.*Mf).* ...
        cos(x(6))+4.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+(-4).*l1.*l2.* ...
        M1.*cos(x(6)+x(7))+(-8).*l1.*l2.*Mf.*cos(x(6)+x(7))+4.*l1.* ...
        la.*Mf.*cos(x(8))+4.*l2.*la.*Mf.*cos(x(7)+x(8))+(-4).*l2.* ...
        la.*Mf.*cos(x(6)+x(7)+x(8))).*x(13)+(4.*I1x+4.*I2x+l1.^2.* ...
        M1+4.*l2.^2.*M1+l2.^2.*M2+4.*l1.^2.*Mf+4.*l2.^2.*Mf+la.^2.* ...
        Mf+(-2).*l2.^2.*(2.*M1+M2+2.*Mf).*cos(x(6))+4.*l1.*l2.*(M1+ ...
        2.*Mf).*cos(x(7))+(-2).*l1.*l2.*M1.*cos(x(6)+x(7))+(-4).* ...
        l1.*l2.*Mf.*cos(x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+4.*l2.* ...
        la.*Mf.*cos(x(7)+x(8))+(-2).*l2.*la.*Mf.*cos(x(6)+x(7)+x(8)) ...
        ).*x(14)+(4.*I1x+l1.^2.*M1+4.*l1.^2.*Mf+la.^2.*Mf+2.*l1.* ...
        l2.*(M1+2.*Mf).*cos(x(7))+(-2).*l1.*l2.*(M1+2.*Mf).*cos(x(6) ...
        +x(7))+4.*l1.*la.*Mf.*cos(x(8))+2.*l2.*la.*Mf.*cos(x(7)+x(8) ...
        )+(-2).*l2.*la.*Mf.*cos(x(6)+x(7)+x(8))).*x(15)+la.*Mf.*(la+ ...
        2.*l1.*cos(x(8))+2.*l2.*cos(x(7)+x(8))+(-2).*l2.*cos(x(6)+x( ...
        7)+x(8))).*x(16));(1/4).*(2.*(l2.*(2.*M1+M2+2.*Mf).*cos(x(3) ...
        +x(4)+x(5)+x(6))+l1.*(M1+2.*Mf).*cos(x(3)+x(4)+x(5)+x(6)+x( ...
        7))+la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))).*x(9)+2.*( ...
        l2.*(2.*M1+M2+2.*Mf).*sin(x(3)+x(4)+x(5)+x(6))+l1.*(M1+2.* ...
        Mf).*sin(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*sin(x(3)+x(4)+x( ...
        5)+x(6)+x(7)+x(8))).*x(10)+4.*(I1x+I2x+(1/4).*l2.*M2.*(l2+( ...
        -2).*l2.*cos(x(6))+(-2).*l1.*cos(x(5)+x(6))+(-2).*la.*cos(x( ...
        4)+x(5)+x(6)))+(-1/4).*M1.*(l1+2.*l2.*cos(x(7))).*((-1).*l1+ ...
        (-2).*l2.*cos(x(7))+2.*l2.*cos(x(6)+x(7))+2.*l1.*cos(x(5)+x( ...
        6)+x(7))+2.*la.*cos(x(4)+x(5)+x(6)+x(7)))+Mf.*((1/2).*la+ ...
        l1.*cos(x(8))+l2.*cos(x(7)+x(8))).*((1/2).*la+l1.*cos(x(8))+ ...
        l2.*cos(x(7)+x(8))+(-1).*l2.*cos(x(6)+x(7)+x(8))+(-1).*l1.* ...
        cos(x(5)+x(6)+x(7)+x(8))+(-1).*la.*cos(x(4)+x(5)+x(6)+x(7)+ ...
        x(8)))+(-1).*l2.*M1.*sin(x(7)).*((-1).*l2.*sin(x(7))+l2.* ...
        sin(x(6)+x(7))+l1.*sin(x(5)+x(6)+x(7))+la.*sin(x(4)+x(5)+x( ...
        6)+x(7)))+(-1).*Mf.*(l1.*sin(x(8))+l2.*sin(x(7)+x(8))).*(( ...
        -1).*l1.*sin(x(8))+(-1).*l2.*sin(x(7)+x(8))+l2.*sin(x(6)+x( ...
        7)+x(8))+l1.*sin(x(5)+x(6)+x(7)+x(8))+la.*sin(x(4)+x(5)+x(6) ...
        +x(7)+x(8)))).*x(11)+(4.*I1x+4.*I2x+l1.^2.*M1+4.*l2.^2.*M1+ ...
        l2.^2.*M2+4.*l1.^2.*Mf+4.*l2.^2.*Mf+la.^2.*Mf+(-2).*l2.^2.*( ...
        2.*M1+M2+2.*Mf).*cos(x(6))+(-2).*l1.*l2.*(2.*M1+M2+2.*Mf).* ...
        cos(x(5)+x(6))+4.*l1.*l2.*M1.*cos(x(7))+8.*l1.*l2.*Mf.*cos( ...
        x(7))+(-2).*l1.*l2.*M1.*cos(x(6)+x(7))+(-4).*l1.*l2.*Mf.* ...
        cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+(-4).* ...
        l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+4.* ...
        l2.*la.*Mf.*cos(x(7)+x(8))+(-2).*l2.*la.*Mf.*cos(x(6)+x(7)+ ...
        x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+x(6)+x(7)+x(8))).*x(12)+( ...
        4.*I1x+4.*I2x+l1.^2.*M1+4.*l2.^2.*M1+l2.^2.*M2+4.*l1.^2.*Mf+ ...
        4.*l2.^2.*Mf+la.^2.*Mf+(-2).*l2.^2.*(2.*M1+M2+2.*Mf).*cos(x( ...
        6))+4.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+(-2).*l1.*l2.*M1.*cos( ...
        x(6)+x(7))+(-4).*l1.*l2.*Mf.*cos(x(6)+x(7))+4.*l1.*la.*Mf.* ...
        cos(x(8))+4.*l2.*la.*Mf.*cos(x(7)+x(8))+(-2).*l2.*la.*Mf.* ...
        cos(x(6)+x(7)+x(8))).*x(13)+(4.*I1x+4.*I2x+l1.^2.*M1+4.* ...
        l2.^2.*M1+l2.^2.*M2+4.*l1.^2.*Mf+4.*l2.^2.*Mf+la.^2.*Mf+4.* ...
        l1.*l2.*(M1+2.*Mf).*cos(x(7))+4.*l1.*la.*Mf.*cos(x(8))+4.* ...
        l2.*la.*Mf.*cos(x(7)+x(8))).*x(14)+(4.*I1x+l1.^2.*M1+4.* ...
        l1.^2.*Mf+la.^2.*Mf+2.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+4.*l1.* ...
        la.*Mf.*cos(x(8))+2.*l2.*la.*Mf.*cos(x(7)+x(8))).*x(15)+la.* ...
        Mf.*(la+2.*l1.*cos(x(8))+2.*l2.*cos(x(7)+x(8))).*x(16));( ...
        1/4).*(2.*(l1.*(M1+2.*Mf).*cos(x(3)+x(4)+x(5)+x(6)+x(7))+ ...
        la.*Mf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))).*x(9)+2.*(l1.*( ...
        M1+2.*Mf).*sin(x(3)+x(4)+x(5)+x(6)+x(7))+la.*Mf.*sin(x(3)+x( ...
        4)+x(5)+x(6)+x(7)+x(8))).*x(10)+(4.*I1x+l1.^2.*M1+4.*l1.^2.* ...
        Mf+la.^2.*Mf+2.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+(-2).*l1.*l2.* ...
        (M1+2.*Mf).*cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x(5)+x(6)+x( ...
        7))+(-4).*l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+(-2).*l1.*la.*M1.* ...
        cos(x(4)+x(5)+x(6)+x(7))+(-4).*l1.*la.*Mf.*cos(x(4)+x(5)+x( ...
        6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+2.*l2.*la.*Mf.*cos(x(7)+x( ...
        8))+(-2).*l2.*la.*Mf.*cos(x(6)+x(7)+x(8))+(-2).*l1.*la.*Mf.* ...
        cos(x(5)+x(6)+x(7)+x(8))+(-2).*la.^2.*Mf.*cos(x(4)+x(5)+x(6) ...
        +x(7)+x(8))).*x(11)+(4.*I1x+l1.^2.*M1+4.*l1.^2.*Mf+la.^2.* ...
        Mf+2.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+(-2).*l1.*l2.*(M1+2.*Mf) ...
        .*cos(x(6)+x(7))+(-2).*l1.^2.*M1.*cos(x(5)+x(6)+x(7))+(-4).* ...
        l1.^2.*Mf.*cos(x(5)+x(6)+x(7))+4.*l1.*la.*Mf.*cos(x(8))+2.* ...
        l2.*la.*Mf.*cos(x(7)+x(8))+(-2).*l2.*la.*Mf.*cos(x(6)+x(7)+ ...
        x(8))+(-2).*l1.*la.*Mf.*cos(x(5)+x(6)+x(7)+x(8))).*x(12)+( ...
        4.*I1x+l1.^2.*M1+4.*l1.^2.*Mf+la.^2.*Mf+2.*l1.*l2.*(M1+2.* ...
        Mf).*cos(x(7))+(-2).*l1.*l2.*(M1+2.*Mf).*cos(x(6)+x(7))+4.* ...
        l1.*la.*Mf.*cos(x(8))+2.*l2.*la.*Mf.*cos(x(7)+x(8))+(-2).* ...
        l2.*la.*Mf.*cos(x(6)+x(7)+x(8))).*x(13)+(4.*I1x+l1.^2.*M1+ ...
        4.*l1.^2.*Mf+la.^2.*Mf+2.*l1.*l2.*(M1+2.*Mf).*cos(x(7))+4.* ...
        l1.*la.*Mf.*cos(x(8))+2.*l2.*la.*Mf.*cos(x(7)+x(8))).*x(14)+ ...
        (4.*I1x+l1.^2.*M1+4.*l1.^2.*Mf+la.^2.*Mf+4.*l1.*la.*Mf.*cos( ...
        x(8))).*x(15)+la.*Mf.*(la+2.*l1.*cos(x(8))).*x(16));(1/4).* ...
        la.*Mf.*(2.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)).*x(9)+2.*sin( ...
        x(3)+x(4)+x(5)+x(6)+x(7)+x(8)).*x(10)+2.*((1/2).*la+l1.*cos( ...
        x(8))+l2.*cos(x(7)+x(8))+(-1).*l2.*cos(x(6)+x(7)+x(8))+(-1) ...
        .*l1.*cos(x(5)+x(6)+x(7)+x(8))+(-1).*la.*cos(x(4)+x(5)+x(6)+ ...
        x(7)+x(8))).*x(11)+(la+2.*l1.*cos(x(8))+2.*l2.*cos(x(7)+x(8) ...
        )+(-2).*l2.*cos(x(6)+x(7)+x(8))+(-2).*l1.*cos(x(5)+x(6)+x(7) ...
        +x(8))).*x(12)+(la+2.*l1.*cos(x(8))+2.*l2.*cos(x(7)+x(8))+( ...
        -2).*l2.*cos(x(6)+x(7)+x(8))).*x(13)+(la+2.*l1.*cos(x(8))+ ...
        2.*l2.*cos(x(7)+x(8))).*x(14)+(la+2.*l1.*cos(x(8))).*x(15)+ ...
        la.*x(16));0;0];

        ref = FullMatrix\DMatrix;

        %Transition map  % Assume locked ankle at impact?     % New transition
        %map from Bobby on 10/12/2014( correctd version)
        out(dim/2+1:dim) = [0, 0, ref(3)+ref(4)+ref(5)+ref(6)+ref(7)+ref(8), -ref(8),-ref(7),-ref(6),-ref(5),-ref(4)];

        out(1) = 0;
        out(2) = 0;
        out(3) = x(3)+x(4)+x(5)+x(6)+x(7)+x(8);
        out(4) = -x(8);
        out(5) = -x(7);
        out(6) = -x(6);
        out(7) = -x(5);
        out(8) = -x(4);
    case 'g'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculate the guard 'g'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%           
        if strcmp(contact,'toe')
        % height function
            qdiff = [cos(slope), -sin(slope); sin(slope), cos(slope)]*[lf;0];  % compensate for inertial frame shifting
            %qdiff = [cos(slope), -sin(slope); sin(slope), cos(slope)]*[0;0];
            out(1) = la.*cos(x(3))+l1.*cos(x(3)+x(4))+l2.*cos(x(3)+x(4)+x(5))+( ...
            -1).*l2.*cos(x(3)+x(4)+x(5)+x(6))+(-1).*l1.*cos(x(3)+x(4)+x( ...
            5)+x(6)+x(7))+(-1).*la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))+( ...
            -1).*tan(slope).*((-1).*la.*sin(x(3))+(-1).*l1.*sin(x(3)+x( ...
            4))+(-1).*l2.*sin(x(3)+x(4)+x(5))+l2.*sin(x(3)+x(4)+x(5)+x( ...
            6))+l1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+la.*sin(x(3)+x(4)+x(5) ...
            +x(6)+x(7)+x(8))+x(1)-qdiff(1))+x(2)-qdiff(2);


            % transverse function
            out(2) = x(10)+(-1).*la.*sin(x(3)).*x(11)+(-1).*l1.*sin(x(3)+x(4)).*( ...
            x(11)+x(12))+(-1).*l2.*sin(x(3)+x(4)+x(5)).*(x(11)+x(12)+x( ...
            13))+l2.*sin(x(3)+x(4)+x(5)+x(6)).*(x(11)+x(12)+x(13)+x(14)) ...
            +l1.*sin(x(3)+x(4)+x(5)+x(6)+x(7)).*(x(11)+x(12)+x(13)+x(14) ...
            +x(15))+la.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)).*(x(11)+x(12) ...
            +x(13)+x(14)+x(15)+x(16))+(-1).*tan(slope).*(x(9)+(-1).*la.* ...
            cos(x(3)).*x(11)+(-1).*l1.*cos(x(3)+x(4)).*(x(11)+x(12))+( ...
            -1).*l2.*cos(x(3)+x(4)+x(5)).*(x(11)+x(12)+x(13))+l2.*cos(x( ...
            3)+x(4)+x(5)+x(6)).*(x(11)+x(12)+x(13)+x(14))+l1.*cos(x(3)+ ...
            x(4)+x(5)+x(6)+x(7)).*(x(11)+x(12)+x(13)+x(14)+x(15))+la.* ...
            cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)).*(x(11)+x(12)+x(13)+x(14) ...
            +x(15)+x(16)));

        else
            out(1) = la.*cos(x(3))+l1.*cos(x(3)+x(4))+l2.*cos(x(3)+x(4)+x(5))+( ...
            -1).*l2.*cos(x(3)+x(4)+x(5)+x(6))+(-1).*l1.*cos(x(3)+x(4)+x( ...
            5)+x(6)+x(7))+(-1).*la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))+( ...
            -1).*tan(slope).*((-1).*la.*sin(x(3))+(-1).*l1.*sin(x(3)+x( ...
            4))+(-1).*l2.*sin(x(3)+x(4)+x(5))+l2.*sin(x(3)+x(4)+x(5)+x( ...
            6))+l1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+la.*sin(x(3)+x(4)+x(5) ...
            +x(6)+x(7)+x(8))+x(1))+x(2);

            out(2) = x(10)+(-1).*la.*sin(x(3)).*x(11)+(-1).*l1.*sin(x(3)+x(4)).*( ...
            x(11)+x(12))+(-1).*l2.*sin(x(3)+x(4)+x(5)).*(x(11)+x(12)+x( ...
            13))+l2.*sin(x(3)+x(4)+x(5)+x(6)).*(x(11)+x(12)+x(13)+x(14)) ...
            +l1.*sin(x(3)+x(4)+x(5)+x(6)+x(7)).*(x(11)+x(12)+x(13)+x(14) ...
            +x(15))+la.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)).*(x(11)+x(12) ...
            +x(13)+x(14)+x(15)+x(16))+(-1).*tan(slope).*(x(9)+(-1).*la.* ...
            cos(x(3)).*x(11)+(-1).*l1.*cos(x(3)+x(4)).*(x(11)+x(12))+( ...
            -1).*l2.*cos(x(3)+x(4)+x(5)).*(x(11)+x(12)+x(13))+l2.*cos(x( ...
            3)+x(4)+x(5)+x(6)).*(x(11)+x(12)+x(13)+x(14))+l1.*cos(x(3)+ ...
            x(4)+x(5)+x(6)+x(7)).*(x(11)+x(12)+x(13)+x(14)+x(15))+la.* ...
            cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8)).*(x(11)+x(12)+x(13)+x(14) ...
            +x(15)+x(16)));

        end
    case 'v'
        % The toe clearance 
        if strcmp(contact,'toe')
        qdiff = [cos(slope), -sin(slope); sin(slope), cos(slope)]*[lf;0];

        out=la.*cos(x(3))+l1.*cos(x(3)+x(4))+l2.*cos(x(3)+x(4)+x(5))+( ...
        -1).*l2.*cos(x(3)+x(4)+x(5)+x(6))+(-1).*l1.*cos(x(3)+x(4)+x( ...
        5)+x(6)+x(7))+(-1).*la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))+( ...
        -1).*lf.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))+tan(slope).*( ...
        lf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))+la.*sin(x(3))+l1.* ...
        sin(x(3)+x(4))+l2.*sin(x(3)+x(4)+x(5))+(-1).*l2.*sin(x(3)+x( ...
        4)+x(5)+x(6))+(-1).*l1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+(-1).* ...
        la.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))+(-1).*(x(1)-qdiff(1)))+x(2)-qdiff(2);
        else
        out=la.*cos(x(3))+l1.*cos(x(3)+x(4))+l2.*cos(x(3)+x(4)+x(5))+( ...
        -1).*l2.*cos(x(3)+x(4)+x(5)+x(6))+(-1).*l1.*cos(x(3)+x(4)+x( ...
        5)+x(6)+x(7))+(-1).*la.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))+( ...
        -1).*lf.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))+tan(slope).*( ...
        lf.*cos(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))+la.*sin(x(3))+l1.* ...
        sin(x(3)+x(4))+l2.*sin(x(3)+x(4)+x(5))+(-1).*l2.*sin(x(3)+x( ...
        4)+x(5)+x(6))+(-1).*l1.*sin(x(3)+x(4)+x(5)+x(6)+x(7))+(-1).* ...
        la.*sin(x(3)+x(4)+x(5)+x(6)+x(7)+x(8))+(-1).*x(1))+x(2);
        end

    otherwise
        disp('invalid flag')
end


