function [xafter, tafter, xbefore, tbefore] = step(xin)
% STEP2   Simulate 1 step and calculate state after impact.
%
% [xafter, tafter, xbefore, tbefore] = step(xin);
%
% INPUTS:
% + xin = input state vector, angles and their rates of change.

% OUTPUTS:
% + xafter = state after impact. If 'allow no contact' specified, xafter =
%   xbefore(end,:).
% + tafter = time at impact. If 'allow no contact' specified, tafter =
%   tbefore(end,:).
% + xbefore = vector of the states at each integration time, up to impact.
% + tbefore = vector of times for each state

global eqnhandle contact stepnum 
global stepclearance_heel stepclearance_toe steplength Step_time 
global lf
global silent
    
    steplength=0;
    tspan = [0 1.0]; 

    %Heel Dynamics
    contact = 'heel';
    if~silent, fprintf([contact,' ']) ;end
    options = odeset('Events', 'guard2heel','RelTol', 1e-8, 'AbsTol', 1e-10);
    [t1,x1,tcontact1,xcontact1,ie] = ode15s(eqnhandle, tspan, xin, options);
    xcontact1_minus = xcontact1(end,1:16);
    xcontact1_plus = dynamics(tcontact1(end),xcontact1_minus','f');   % Foot-slap impact map
 
    %Flat foot dynamics
    contact = 'flat';
    if~silent, fprintf([contact,' ']) ;end
    options = odeset('Events', 'guard2toe','RelTol', 1e-8, 'AbsTol', 1e-10);
    xin2 = xcontact1_plus';
    [t2,x2, tcontact2,xcontact2,ie] = ode15s(eqnhandle, tspan+tcontact1(end), xin2, options); 
    xcontact2_minus = xcontact2(end,1:16);
    xcontact2_plus = dynamics(tcontact2,xcontact2_minus','h');   % Toe-off "impact"  map
    
    %Toe Dynamics
    contact = 'toe';
    if~silent,fprintf([contact,' ']);end
    options = odeset('Events', 'guard2','RelTol', 1e-8, 'AbsTol', 1e-10);
    contact = 'toe';
    xin3 = xcontact2_plus';
    [t3, x3, tcontact3, xcontact3] = ode15s(eqnhandle, tspan+tcontact2(end), xin3 , options);
    x = [x1;x2;x3];
    t = [t1;t2;t3];
    
    startCoords = newStepCoords(x(1,:));
    stopCoords = newStepCoords(x(end,:));
    steplength=sqrt((startCoords(2,1)-stopCoords(2,1))^2 + (startCoords(2,2)-stopCoords(2,2))^2);
    
    stepclearance_heel = zeros(length(t),2);
    stepclearance_toe = zeros(length(t),1);
    for i=1:length(t)
        stepclearance_heel(i,:)=dynamics(t(i),x(i,:)','g');
        stepclearance_toe(i)=dynamics(t(i),x(i,:)','v');
    end
    
    %Format Outputs, check for early impacts, etc...   
    xafter = feval(eqnhandle, 0, xcontact3, 'i');   % switches stance/swing leg to swing/stance leg
    tafter = tcontact3;
    xbefore = x;        
    tbefore = t;    

end